/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_vSwell.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_vSwell *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_vSwell_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwell));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwell(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_vSwell_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwell));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwell(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_vSwell_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_vSwell();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_vSwell::Heavy_vSwell(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sTabwrite_init(&sTabwrite_8YX3EPBE, &hTable_6m1i5BNE);
  numBytes += sTabread_init(&sTabread_mqqAdMNR, &hTable_6m1i5BNE, true);
  numBytes += sRPole_init(&sRPole_atEW7q7c);
  numBytes += sEnv_init(&sEnv_snslWM2R, 1024, 512);
  numBytes += sLine_init(&sLine_BezNSOW6);
  numBytes += cSlice_init(&cSlice_jZPFs3Pa, 1, -1);
  numBytes += cSlice_init(&cSlice_C3ruHQ1y, 1, -1);
  numBytes += cVar_init_f(&cVar_mAydGJYG, 0.0f);
  numBytes += cIf_init(&cIf_q7TWCEnM, false);
  numBytes += cBinop_init(&cBinop_5gTfgAg2, 0.0f); // __neq
  numBytes += cSlice_init(&cSlice_7VPbJHnd, 1, -1);
  numBytes += cSlice_init(&cSlice_p1cq5hbv, 1, -1);
  numBytes += cVar_init_f(&cVar_XsG1XrFt, 0.0f);
  numBytes += cIf_init(&cIf_Mo0tyTfh, false);
  numBytes += cBinop_init(&cBinop_nIzG9Bkq, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_ZaWooGE1, 0.0f);
  numBytes += cVar_init_f(&cVar_tOZysBtI, 0.0f);
  numBytes += cBinop_init(&cBinop_dfckWdhJ, 0.0f); // __gt
  numBytes += cBinop_init(&cBinop_68N4esNu, 0.0f); // __lt
  numBytes += cSlice_init(&cSlice_qRkKKr90, 2, 1);
  numBytes += cSlice_init(&cSlice_7uiBNeIG, 1, 1);
  numBytes += cSlice_init(&cSlice_gOqcKDlb, 0, 1);
  numBytes += cVar_init_f(&cVar_AsQPnQUF, 0.0f);
  numBytes += cIf_init(&cIf_kWK8ktFV, false);
  numBytes += cIf_init(&cIf_hlxHUpRv, false);
  numBytes += cIf_init(&cIf_jhx1syLy, false);
  numBytes += cIf_init(&cIf_5l7cExWi, false);
  numBytes += cIf_init(&cIf_PniLnrmH, false);
  numBytes += cBinop_init(&cBinop_enM2Xdga, 0.0f); // __eq
  numBytes += cDelay_init(this, &cDelay_XEag6QEu, 10.0f);
  numBytes += cPack_init(&cPack_5hiHPDkp, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_NvWXuOBw, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_AAudHFdI, 10.0f);
  numBytes += cPack_init(&cPack_VCQnPfRS, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_EQONWyXy, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_meuw9Wv3, 10.0f);
  numBytes += cPack_init(&cPack_WyVZXNkK, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_9oMUutVY, 1e-07f);
  numBytes += cIf_init(&cIf_ENtuxI01, true);
  numBytes += cVar_init_f(&cVar_nAL51q38, 1e-07f);
  numBytes += cVar_init_f(&cVar_Ujqn5B4c, 1e-07f);
  numBytes += sVarf_init(&sVarf_fzlcNhf9, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_ZIXAF6sI, 0.0f);
  numBytes += cVar_init_f(&cVar_GF8y1ABq, 20.0f);
  numBytes += cBinop_init(&cBinop_HW3VoGZb, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_TJm0knBm, 0.0f);
  numBytes += cSlice_init(&cSlice_EqJAUSMY, 1, -1);
  numBytes += cSlice_init(&cSlice_xnb3BmAC, 1, -1);
  numBytes += cVar_init_f(&cVar_1QgcpgdV, 0.0f);
  numBytes += cVar_init_f(&cVar_Hn8Y9KG0, 20.0f);
  numBytes += cVar_init_f(&cVar_LQdCofB3, 0.0f);
  numBytes += cVar_init_f(&cVar_g1HhU4T4, 0.0f);
  numBytes += cVar_init_f(&cVar_0VDNPViY, 0.0f);
  numBytes += cSlice_init(&cSlice_lkCjiPC7, 1, 1);
  numBytes += cSlice_init(&cSlice_mN7HjAVA, 0, 1);
  numBytes += cBinop_init(&cBinop_gtuAQdnG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_l57OLQQT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OS97a4Fb, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_DwYXyudI, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_s5WqOUBc, 20.0f); // __div
  numBytes += cBinop_init(&cBinop_1QyrWd3l, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_mWd0Efth, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_srWX1ZnE, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_QsCxcNXl, 5.0f);
  numBytes += cVar_init_f(&cVar_ghIpJIpz, 500.0f);
  numBytes += cBinop_init(&cBinop_KwwBlsQa, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_7LXMyjmW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jmTHfqE8, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_ZNEsC6u8, 0.0f);
  numBytes += cDelay_init(this, &cDelay_UzhKvguc, 0.0f);
  numBytes += hTable_init(&hTable_6m1i5BNE, 256);
  numBytes += cTabhead_init(&cTabhead_fwQWuPFc, &hTable_6m1i5BNE);
  numBytes += cVar_init_s(&cVar_5VemrPRy, "del-1001-swell");
  numBytes += cDelay_init(this, &cDelay_ZlPOquOz, 8.0f);
  numBytes += cDelay_init(this, &cDelay_NGVJghBN, 0.0f);
  numBytes += cBinop_init(&cBinop_FN4IT242, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_p21IZPGu, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_5vP9w80D, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_m7ZJ2kfg, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_zPTfGL8p, 2.0f); // __sub
  numBytes += sVarf_init(&sVarf_7I71UFmw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_d0bikSMm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zAssTYCd, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_vSwell::~Heavy_vSwell() {
  sEnv_free(&sEnv_snslWM2R);
  cPack_free(&cPack_5hiHPDkp);
  cPack_free(&cPack_VCQnPfRS);
  cPack_free(&cPack_WyVZXNkK);
  hTable_free(&hTable_6m1i5BNE);
}

HvTable *Heavy_vSwell::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xB4039215: return &hTable_6m1i5BNE; // del-1001-swell
    default: return nullptr;
  }
}

void Heavy_vSwell::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xCFF35931: { // Attack_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NOaODW6I_sendMessage);
      break;
    }
    case 0x4397AE0: { // Attack_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_q2GZA6cK_sendMessage);
      break;
    }
    case 0x73ACB90E: { // Mid_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KASih03w_sendMessage);
      break;
    }
    case 0x4675584E: { // Mid_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FNvI9UDj_sendMessage);
      break;
    }
    case 0x558F437A: { // Release_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_c2hhDQQI_sendMessage);
      break;
    }
    case 0x8D204657: { // Shape
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TM7Af2yn_sendMessage);
      break;
    }
    case 0x2D669F6F: { // SubEnv_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mZxXXkrP_sendMessage);
      break;
    }
    case 0x7BABB594: { // Threshold_High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gGPOHLYc_sendMessage);
      break;
    }
    case 0xA0E82E9F: { // Threshold_Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XOVOfYRX_sendMessage);
      break;
    }
    case 0x145892E8: { // Threshold_Strict
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XHZQBboD_sendMessage);
      break;
    }
    case 0xCB36B160: { // Trigger_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ag4G1gks_sendMessage);
      break;
    }
    case 0x5DF5B524: { // Trigger_EXT
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xbN8j2Z0_sendMessage);
      break;
    }
    case 0xE7A7BB75: { // Trigger_by_Audio_ON
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_K8OqLLmn_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NndMLYGi_sendMessage);
      break;
    }
    case 0x67E37CA3: { // __hv_notein
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_meGzIDpH_sendMessage);
      break;
    }
    case 0xA2F0F2D3: { // ecancel
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SdCXEuUK_sendMessage);
      break;
    }
    case 0xC698CFF8: { // subenv
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bYE7z1C9_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_vSwell::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Attack_Level";
        info->hash = 0xCFF35931;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.6f;
        break;
      }
      case 1: {
        info->name = "Attack_ms";
        info->hash = 0x4397AE0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 3000.0f;
        info->defaultVal = 400.0f;
        break;
      }
      case 2: {
        info->name = "Mid_Level";
        info->hash = 0x73ACB90E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.65f;
        break;
      }
      case 3: {
        info->name = "Mid_ms";
        info->hash = 0x4675584E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 4: {
        info->name = "Release_ms";
        info->hash = 0x558F437A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 2200.0f;
        break;
      }
      case 5: {
        info->name = "Shape";
        info->hash = 0x8D204657;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.1f;
        info->maxVal = 3.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 6: {
        info->name = "SubEnv_Level";
        info->hash = 0x2D669F6F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1e-07f;
        info->maxVal = 0.7f;
        info->defaultVal = 1e-07f;
        break;
      }
      case 7: {
        info->name = "Threshold_High";
        info->hash = 0x7BABB594;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 30.0f;
        info->maxVal = 85.0f;
        info->defaultVal = 52.0f;
        break;
      }
      case 8: {
        info->name = "Threshold_Low";
        info->hash = 0xA0E82E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.3f;
        info->maxVal = 8.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 9: {
        info->name = "Threshold_Strict";
        info->hash = 0x145892E8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "Trigger_Delay";
        info->hash = 0xCB36B160;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 50.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 11: {
        info->name = "Trigger_EXT";
        info->hash = 0x5DF5B524;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Trigger_by_Audio_ON";
        info->hash = 0xE7A7BB75;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 13;
}



/*
 * Send Function Implementations
 */


void Heavy_vSwell::sEnv_snslWM2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dfckWdhJ, HV_BINOP_GREATER_THAN, 0, m, &cBinop_dfckWdhJ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_68N4esNu, HV_BINOP_LESS_THAN, 0, m, &cBinop_68N4esNu_sendMessage);
}

void Heavy_vSwell::cSwitchcase_EKSw34RE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jZPFs3Pa, 0, m, &cSlice_jZPFs3Pa_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_C3ruHQ1y, 0, m, &cSlice_C3ruHQ1y_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HAC9IFQU_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2kmEJwJU_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_jZPFs3Pa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_mAydGJYG, 0, m, &cVar_mAydGJYG_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_mAydGJYG, 0, m, &cVar_mAydGJYG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_C3ruHQ1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_5gTfgAg2, HV_BINOP_NEQ, 1, m, &cBinop_5gTfgAg2_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_mAydGJYG, 1, m, &cVar_mAydGJYG_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_5gTfgAg2, HV_BINOP_NEQ, 1, m, &cBinop_5gTfgAg2_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_mAydGJYG, 1, m, &cVar_mAydGJYG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_mAydGJYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_l5hurNa9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cIf_q7TWCEnM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tKuwHdxt_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XQLGilYY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cCast_XQLGilYY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mAydGJYG, 0, m, &cVar_mAydGJYG_sendMessage);
}

void Heavy_vSwell::cCast_tKuwHdxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5gTfgAg2, HV_BINOP_NEQ, 1, m, &cBinop_5gTfgAg2_sendMessage);
}

void Heavy_vSwell::cBinop_5gTfgAg2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q7TWCEnM, 1, m, &cIf_q7TWCEnM_sendMessage);
}

void Heavy_vSwell::cCast_HAC9IFQU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5gTfgAg2, HV_BINOP_NEQ, 0, m, &cBinop_5gTfgAg2_sendMessage);
}

void Heavy_vSwell::cCast_2kmEJwJU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q7TWCEnM, 0, m, &cIf_q7TWCEnM_sendMessage);
}

void Heavy_vSwell::cSwitchcase_Y3mrz4RY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7VPbJHnd, 0, m, &cSlice_7VPbJHnd_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_p1cq5hbv, 0, m, &cSlice_p1cq5hbv_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Y8W6ghvP_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rr864ZaP_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_7VPbJHnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_XsG1XrFt, 0, m, &cVar_XsG1XrFt_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_XsG1XrFt, 0, m, &cVar_XsG1XrFt_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_p1cq5hbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_nIzG9Bkq, HV_BINOP_NEQ, 1, m, &cBinop_nIzG9Bkq_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_XsG1XrFt, 1, m, &cVar_XsG1XrFt_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_nIzG9Bkq, HV_BINOP_NEQ, 1, m, &cBinop_nIzG9Bkq_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_XsG1XrFt, 1, m, &cVar_XsG1XrFt_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_XsG1XrFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7ADg6cnK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cIf_Mo0tyTfh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sSKxXYNc_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_k9ShkCqA_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cCast_sSKxXYNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nIzG9Bkq, HV_BINOP_NEQ, 1, m, &cBinop_nIzG9Bkq_sendMessage);
}

void Heavy_vSwell::cCast_k9ShkCqA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XsG1XrFt, 0, m, &cVar_XsG1XrFt_sendMessage);
}

void Heavy_vSwell::cBinop_nIzG9Bkq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Mo0tyTfh, 1, m, &cIf_Mo0tyTfh_sendMessage);
}

void Heavy_vSwell::cCast_rr864ZaP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Mo0tyTfh, 0, m, &cIf_Mo0tyTfh_sendMessage);
}

void Heavy_vSwell::cCast_Y8W6ghvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nIzG9Bkq, HV_BINOP_NEQ, 0, m, &cBinop_nIzG9Bkq_sendMessage);
}

void Heavy_vSwell::cSwitchcase_l5hurNa9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nkSBKHzA_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ogrMB5EB_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_nkSBKHzA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tOZysBtI, 0, m, &cVar_tOZysBtI_sendMessage);
}

void Heavy_vSwell::cCast_ogrMB5EB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ibIBnrzf_sendMessage(_c, 0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ENtuxI01, 0, m, &cIf_ENtuxI01_sendMessage);
}

void Heavy_vSwell::cSwitchcase_7ADg6cnK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8j8a5npo_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1yTwCkaM_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_8j8a5npo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZaWooGE1, 0, m, &cVar_ZaWooGE1_sendMessage);
}

void Heavy_vSwell::cCast_1yTwCkaM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O0by1yLp_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_ZaWooGE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dfckWdhJ, HV_BINOP_GREATER_THAN, 1, m, &cBinop_dfckWdhJ_sendMessage);
}

void Heavy_vSwell::cVar_tOZysBtI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_68N4esNu, HV_BINOP_LESS_THAN, 1, m, &cBinop_68N4esNu_sendMessage);
}

void Heavy_vSwell::cBinop_dfckWdhJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_EKSw34RE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cBinop_68N4esNu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Y3mrz4RY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_ibIBnrzf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dfckWdhJ, HV_BINOP_GREATER_THAN, 1, m, &cBinop_dfckWdhJ_sendMessage);
}

void Heavy_vSwell::cMsg_O0by1yLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, -1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_68N4esNu, HV_BINOP_LESS_THAN, 1, m, &cBinop_68N4esNu_sendMessage);
}

void Heavy_vSwell::cSlice_qRkKKr90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ug2IdYPJ_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_7uiBNeIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_5l7cExWi, 0, m, &cIf_5l7cExWi_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_hlxHUpRv, 0, m, &cIf_hlxHUpRv_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_gOqcKDlb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_PniLnrmH, 0, m, &cIf_PniLnrmH_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_jhx1syLy, 0, m, &cIf_jhx1syLy_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_AsQPnQUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_B1g7QHAA_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_kWK8ktFV, 0, m, &cIf_kWK8ktFV_sendMessage);
}

void Heavy_vSwell::cUnop_rRguzkJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lhNyZWVT_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_enM2Xdga, HV_BINOP_EQ, 1, m, &cBinop_enM2Xdga_sendMessage);
}

void Heavy_vSwell::cUnop_Nor0BPcS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lhNyZWVT_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_enM2Xdga, HV_BINOP_EQ, 1, m, &cBinop_enM2Xdga_sendMessage);
}

void Heavy_vSwell::cIf_kWK8ktFV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_Nor0BPcS_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_rRguzkJr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_B1g7QHAA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kWK8ktFV, 1, m, &cIf_kWK8ktFV_sendMessage);
}

void Heavy_vSwell::cIf_hlxHUpRv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ZFt9jXEk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_jhx1syLy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_5l7cExWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ZFt9jXEk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_PniLnrmH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_ug2IdYPJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_enM2Xdga, HV_BINOP_EQ, 0, m, &cBinop_enM2Xdga_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_TgCKJUWk_sendMessage);
}

void Heavy_vSwell::cBinop_lhNyZWVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RV7sxujL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pjzqRHid_sendMessage);
}

void Heavy_vSwell::cBinop_enM2Xdga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PuItF0QU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bZqVH9Dk_sendMessage);
}

void Heavy_vSwell::cCast_bZqVH9Dk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PniLnrmH, 1, m, &cIf_PniLnrmH_sendMessage);
}

void Heavy_vSwell::cCast_PuItF0QU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hlxHUpRv, 1, m, &cIf_hlxHUpRv_sendMessage);
}

void Heavy_vSwell::cCast_pjzqRHid_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jhx1syLy, 1, m, &cIf_jhx1syLy_sendMessage);
}

void Heavy_vSwell::cCast_RV7sxujL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5l7cExWi, 1, m, &cIf_5l7cExWi_sendMessage);
}

void Heavy_vSwell::cBinop_TgCKJUWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_vSwell::cSwitchcase_lLXTi7jC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_neG5BynG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_neG5BynG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_XEag6QEu, 1, m, &cDelay_XEag6QEu_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DzGYUOpD_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_XEag6QEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XEag6QEu, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_byFXRt5B_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6W4KspOJ_sendMessage);
  cSwitchcase_CNahkTwm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_neG5BynG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_XEag6QEu, 0, m, &cDelay_XEag6QEu_sendMessage);
}

void Heavy_vSwell::cCast_DzGYUOpD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XEag6QEu, 0, m, &cDelay_XEag6QEu_sendMessage);
}

void Heavy_vSwell::cPack_5hiHPDkp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jNXjSiKl_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_NvWXuOBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ebplqSfA_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_pEaJJvXk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_lLXTi7jC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_8mtWZ8l5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_5hiHPDkp, 0, m, &cPack_5hiHPDkp_sendMessage);
}

void Heavy_vSwell::cCast_uFAOkFy9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NvWXuOBw, 0, m, &cVar_NvWXuOBw_sendMessage);
}

void Heavy_vSwell::cMsg_ebplqSfA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_BezNSOW6, 0, m, NULL);
}

void Heavy_vSwell::cMsg_jNXjSiKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_BezNSOW6, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_CNahkTwm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_SFUwxmGw_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_SFUwxmGw_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_AAudHFdI, 1, m, &cDelay_AAudHFdI_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rxxrxeQH_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_AAudHFdI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AAudHFdI, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Bs1tJPm5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_12Kp6Bk1_sendMessage);
  cSwitchcase_VN7csrgs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_SFUwxmGw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AAudHFdI, 0, m, &cDelay_AAudHFdI_sendMessage);
}

void Heavy_vSwell::cCast_rxxrxeQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AAudHFdI, 0, m, &cDelay_AAudHFdI_sendMessage);
}

void Heavy_vSwell::cPack_VCQnPfRS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UQeAYN9r_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_EQONWyXy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0bGQVjKO_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_yMQyPyYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_CNahkTwm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_byFXRt5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EQONWyXy, 0, m, &cVar_EQONWyXy_sendMessage);
}

void Heavy_vSwell::cCast_6W4KspOJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_VCQnPfRS, 0, m, &cPack_VCQnPfRS_sendMessage);
}

void Heavy_vSwell::cMsg_0bGQVjKO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_BezNSOW6, 0, m, NULL);
}

void Heavy_vSwell::cMsg_UQeAYN9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_BezNSOW6, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_VN7csrgs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_m2BrlF56_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_m2BrlF56_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_meuw9Wv3, 1, m, &cDelay_meuw9Wv3_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1UU5wx8Z_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_meuw9Wv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_meuw9Wv3, m);
}

void Heavy_vSwell::cMsg_m2BrlF56_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_meuw9Wv3, 0, m, &cDelay_meuw9Wv3_sendMessage);
}

void Heavy_vSwell::cCast_1UU5wx8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_meuw9Wv3, 0, m, &cDelay_meuw9Wv3_sendMessage);
}

void Heavy_vSwell::cPack_WyVZXNkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ug9qGsx5_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_9oMUutVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i8WglQKq_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_3MaxPmlR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_VN7csrgs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_12Kp6Bk1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_WyVZXNkK, 0, m, &cPack_WyVZXNkK_sendMessage);
}

void Heavy_vSwell::cCast_Bs1tJPm5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9oMUutVY, 0, m, &cVar_9oMUutVY_sendMessage);
}

void Heavy_vSwell::cMsg_i8WglQKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_BezNSOW6, 0, m, NULL);
}

void Heavy_vSwell::cMsg_ug9qGsx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_BezNSOW6, 0, m, NULL);
}

void Heavy_vSwell::cIf_ENtuxI01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kWffPOzr_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V0dwKiDY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSwitchcase_dII8J2No_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sF2qRG37_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_sF2qRG37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kWffPOzr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V0dwKiDY_sendMessage);
}

void Heavy_vSwell::cVar_nAL51q38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lXP1Kvxz_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_Ujqn5B4c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_WyVZXNkK, 1, m, &cPack_WyVZXNkK_sendMessage);
}

void Heavy_vSwell::cMsg_zQZs0CFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_04NSgjIZ_sendMessage);
}

void Heavy_vSwell::cSystem_04NSgjIZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_l57OLQQT, HV_BINOP_MULTIPLY, 1, m, &cBinop_l57OLQQT_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gtuAQdnG, HV_BINOP_MULTIPLY, 1, m, &cBinop_gtuAQdnG_sendMessage);
}

void Heavy_vSwell::cSwitchcase_L6cpp22J_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_8f7hku9h_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_8f7hku9h_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BnC3cihC_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_ZIXAF6sI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZIXAF6sI, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZIXAF6sI, 0, m, &cDelay_ZIXAF6sI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TJm0knBm, 0, m, &cVar_TJm0knBm_sendMessage);
}

void Heavy_vSwell::cCast_BnC3cihC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8f7hku9h_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZIXAF6sI, 0, m, &cDelay_ZIXAF6sI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TJm0knBm, 0, m, &cVar_TJm0knBm_sendMessage);
}

void Heavy_vSwell::cMsg_WJIVLqW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_C8boggNI_sendMessage);
}

void Heavy_vSwell::cSystem_C8boggNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_chUnHbKP_sendMessage);
}

void Heavy_vSwell::cVar_GF8y1ABq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HW3VoGZb, HV_BINOP_MULTIPLY, 0, m, &cBinop_HW3VoGZb_sendMessage);
}

void Heavy_vSwell::cMsg_8f7hku9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZIXAF6sI, 0, m, &cDelay_ZIXAF6sI_sendMessage);
}

void Heavy_vSwell::cBinop_3y4xF1sF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZIXAF6sI, 2, m, &cDelay_ZIXAF6sI_sendMessage);
}

void Heavy_vSwell::cBinop_chUnHbKP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HW3VoGZb, HV_BINOP_MULTIPLY, 1, m, &cBinop_HW3VoGZb_sendMessage);
}

void Heavy_vSwell::cBinop_HW3VoGZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_3y4xF1sF_sendMessage);
}

void Heavy_vSwell::cVar_TJm0knBm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OS97a4Fb, HV_BINOP_SUBTRACT, 0, m, &cBinop_OS97a4Fb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_LESS_THAN_EQL, 0.0f, 0, m, &cBinop_oLzKdThs_sendMessage);
}

void Heavy_vSwell::cSwitchcase_9ALPtWEP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lA5THhH2_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9FdGaS4V_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_lA5THhH2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0VDNPViY, 0, m, &cVar_0VDNPViY_sendMessage);
}

void Heavy_vSwell::cCast_9FdGaS4V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zatomjpw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jO6M1MX0_sendMessage);
}

void Heavy_vSwell::cSwitchcase_xkLW81KQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cSlice_onMessage(_c, &Context(_c)->cSlice_EqJAUSMY, 0, m, &cSlice_EqJAUSMY_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xnb3BmAC, 0, m, &cSlice_xnb3BmAC_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w2Ocfgbm_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_lkCjiPC7, 0, m, &cSlice_lkCjiPC7_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_mN7HjAVA, 0, m, &cSlice_mN7HjAVA_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_25r7LSj5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ArXaKoNg_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_EqJAUSMY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_SLqj7Ms5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cMsg_SLqj7Ms5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_xnb3BmAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0RnN6Qoi_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q8n1GQZd_sendMessage);
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0RnN6Qoi_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q8n1GQZd_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_1QgcpgdV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N9jYrVss_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lYvGXlJJ_sendMessage);
}

void Heavy_vSwell::cVar_Hn8Y9KG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_GtHEjGpj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_GtHEjGpj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DNu1VkFN_sendMessage);
      break;
    }
    default: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_l57OLQQT, HV_BINOP_MULTIPLY, 0, m, &cBinop_l57OLQQT_sendMessage);
      cBinop_onMessage(_c, &Context(_c)->cBinop_s5WqOUBc, HV_BINOP_DIVIDE, 1, m, &cBinop_s5WqOUBc_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_GF8y1ABq, 0, m, &cVar_GF8y1ABq_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cCast_DNu1VkFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_53GWacqN_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_LQdCofB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_srWX1ZnE, HV_BINOP_SUBTRACT, 1, m, &cBinop_srWX1ZnE_sendMessage);
}

void Heavy_vSwell::cVar_g1HhU4T4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0VDNPViY, 0, m, &cVar_0VDNPViY_sendMessage);
}

void Heavy_vSwell::cVar_0VDNPViY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DwYXyudI, HV_BINOP_ADD, 0, m, &cBinop_DwYXyudI_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mWd0Efth, HV_BINOP_ADD, 0, m, &cBinop_mWd0Efth_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_fzlcNhf9, m);
}

void Heavy_vSwell::cSlice_lkCjiPC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N9jYrVss_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lYvGXlJJ_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_mN7HjAVA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yzlk2eaX_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IoxCGfhw_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_5zi7jhKJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TJm0knBm, 1, m, &cVar_TJm0knBm_sendMessage);
}

void Heavy_vSwell::cBinop_gtuAQdnG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_5zi7jhKJ_sendMessage);
}

void Heavy_vSwell::cBinop_l57OLQQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_B7lE7FJi_sendMessage);
}

void Heavy_vSwell::cBinop_B7lE7FJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OS97a4Fb, HV_BINOP_SUBTRACT, 1, m, &cBinop_OS97a4Fb_sendMessage);
}

void Heavy_vSwell::cBinop_OS97a4Fb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TJm0knBm, 1, m, &cVar_TJm0knBm_sendMessage);
}

void Heavy_vSwell::cMsg_bgYHVTFR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cSwitchcase_L6cpp22J_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_oeY6l5T6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_L6cpp22J_onMessage(_c, NULL, 0, m, NULL);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mWd0Efth, HV_BINOP_ADD, 1, m, &cBinop_mWd0Efth_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DwYXyudI, HV_BINOP_ADD, 1, m, &cBinop_DwYXyudI_sendMessage);
}

void Heavy_vSwell::cBinop_oLzKdThs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9ALPtWEP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cBinop_DwYXyudI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0VDNPViY, 1, m, &cVar_0VDNPViY_sendMessage);
}

void Heavy_vSwell::cBinop_s5WqOUBc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1QyrWd3l, HV_BINOP_DIVIDE, 1, m, &cBinop_1QyrWd3l_sendMessage);
}

void Heavy_vSwell::cBinop_1QyrWd3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mWd0Efth, HV_BINOP_ADD, 1, m, &cBinop_mWd0Efth_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DwYXyudI, HV_BINOP_ADD, 1, m, &cBinop_DwYXyudI_sendMessage);
}

void Heavy_vSwell::cCast_lYvGXlJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s5WqOUBc, HV_BINOP_DIVIDE, 0, m, &cBinop_s5WqOUBc_sendMessage);
}

void Heavy_vSwell::cCast_N9jYrVss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gtuAQdnG, HV_BINOP_MULTIPLY, 0, m, &cBinop_gtuAQdnG_sendMessage);
}

void Heavy_vSwell::cCast_IoxCGfhw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_srWX1ZnE, HV_BINOP_SUBTRACT, 0, m, &cBinop_srWX1ZnE_sendMessage);
}

void Heavy_vSwell::cCast_yzlk2eaX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_g1HhU4T4, 1, m, &cVar_g1HhU4T4_sendMessage);
}

void Heavy_vSwell::cCast_zatomjpw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oeY6l5T6_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_jO6M1MX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_g1HhU4T4, 0, m, &cVar_g1HhU4T4_sendMessage);
}

void Heavy_vSwell::cBinop_mWd0Efth_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LQdCofB3, 0, m, &cVar_LQdCofB3_sendMessage);
}

void Heavy_vSwell::cMsg_SLqj7Ms5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_L6cpp22J_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_p336uaRl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_1QgcpgdV, 1, m, &cVar_1QgcpgdV_sendMessage);
}

void Heavy_vSwell::cMsg_53GWacqN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 20.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_l57OLQQT, HV_BINOP_MULTIPLY, 0, m, &cBinop_l57OLQQT_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_s5WqOUBc, HV_BINOP_DIVIDE, 1, m, &cBinop_s5WqOUBc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GF8y1ABq, 0, m, &cVar_GF8y1ABq_sendMessage);
}

void Heavy_vSwell::cCast_0RnN6Qoi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SLqj7Ms5_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_Q8n1GQZd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_p6kzVR7b_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mWd0Efth, HV_BINOP_ADD, 0, m, &cBinop_mWd0Efth_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0VDNPViY, 1, m, &cVar_0VDNPViY_sendMessage);
}

void Heavy_vSwell::cBinop_srWX1ZnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1QyrWd3l, HV_BINOP_DIVIDE, 0, m, &cBinop_1QyrWd3l_sendMessage);
}

void Heavy_vSwell::cCast_p6kzVR7b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oeY6l5T6_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_ArXaKoNg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p336uaRl_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_25r7LSj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bgYHVTFR_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_w2Ocfgbm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1QgcpgdV, 0, m, &cVar_1QgcpgdV_sendMessage);
}

void Heavy_vSwell::cSwitchcase_NetDGfMy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_bgznUTdm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_bgznUTdm_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_QsCxcNXl, 1, m, &cDelay_QsCxcNXl_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_B3cytmgu_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_QsCxcNXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QsCxcNXl, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uFAOkFy9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8mtWZ8l5_sendMessage);
  cSwitchcase_lLXTi7jC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_bgznUTdm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_QsCxcNXl, 0, m, &cDelay_QsCxcNXl_sendMessage);
}

void Heavy_vSwell::cCast_B3cytmgu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_QsCxcNXl, 0, m, &cDelay_QsCxcNXl_sendMessage);
}

void Heavy_vSwell::cVar_ghIpJIpz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KwwBlsQa, HV_BINOP_MULTIPLY, 0, m, &cBinop_KwwBlsQa_sendMessage);
}

void Heavy_vSwell::cMsg_9j2ZHxoG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dmUFjqR7_sendMessage);
}

void Heavy_vSwell::cSystem_dmUFjqR7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ruCXm1rD_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_KwwBlsQa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Az2z5uJD_sendMessage);
}

void Heavy_vSwell::cBinop_247Mb6jy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KwwBlsQa, HV_BINOP_MULTIPLY, 1, m, &cBinop_KwwBlsQa_sendMessage);
}

void Heavy_vSwell::cMsg_ruCXm1rD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_247Mb6jy_sendMessage);
}

void Heavy_vSwell::cBinop_Az2z5uJD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_UiafoXw9_sendMessage);
}

void Heavy_vSwell::cBinop_UiafoXw9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_aPAbK9Sh_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_jmTHfqE8, m);
}

void Heavy_vSwell::cBinop_aPAbK9Sh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_7LXMyjmW, m);
}

void Heavy_vSwell::cMsg_gPtTOCQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Lmpvadnd_sendMessage);
}

void Heavy_vSwell::cSystem_Lmpvadnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_hzBcgxt5_sendMessage);
}

void Heavy_vSwell::cDelay_ZNEsC6u8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZNEsC6u8, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UzhKvguc, 0, m, &cDelay_UzhKvguc_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZNEsC6u8, 0, m, &cDelay_ZNEsC6u8_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_8YX3EPBE, 1, m, NULL);
}

void Heavy_vSwell::cDelay_UzhKvguc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UzhKvguc, m);
  cMsg_yvn0ZH9b_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cSwitchcase_xnku7c2U_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_LePE19uZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cBinop_MgwwV9z5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DKh5VbwQ_sendMessage(_c, 0, m);
}

void Heavy_vSwell::hTable_6m1i5BNE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gJxhuCX7_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZNEsC6u8, 2, m, &cDelay_ZNEsC6u8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gJsojgV2_sendMessage);
}

void Heavy_vSwell::cMsg_DKh5VbwQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_6m1i5BNE, 0, m, &hTable_6m1i5BNE_sendMessage);
}

void Heavy_vSwell::cBinop_hzBcgxt5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_MgwwV9z5_sendMessage);
}

void Heavy_vSwell::cMsg_yvn0ZH9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_6m1i5BNE, 0, m, &hTable_6m1i5BNE_sendMessage);
}

void Heavy_vSwell::cCast_gJsojgV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZNEsC6u8, 0, m, &cDelay_ZNEsC6u8_sendMessage);
}

void Heavy_vSwell::cMsg_gJxhuCX7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_UzhKvguc, 2, m, &cDelay_UzhKvguc_sendMessage);
}

void Heavy_vSwell::cMsg_LePE19uZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_8YX3EPBE, 1, m, NULL);
}

void Heavy_vSwell::cTabhead_fwQWuPFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p21IZPGu, HV_BINOP_SUBTRACT, 0, m, &cBinop_p21IZPGu_sendMessage);
}

void Heavy_vSwell::cMsg_5XdSssus_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WocATEVP_sendMessage);
}

void Heavy_vSwell::cSystem_WocATEVP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_OfPzIDth_sendMessage);
}

void Heavy_vSwell::cVar_5VemrPRy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hs6WArQ2_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cDelay_ZlPOquOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZlPOquOz, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NGVJghBN, 0, m, &cDelay_NGVJghBN_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_mqqAdMNR, 0, m, &sTabread_mqqAdMNR_sendMessage);
}

void Heavy_vSwell::cDelay_NGVJghBN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NGVJghBN, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_mqqAdMNR, 0, m, &sTabread_mqqAdMNR_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NGVJghBN, 0, m, &cDelay_NGVJghBN_sendMessage);
}

void Heavy_vSwell::sTabread_mqqAdMNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_m7ZJ2kfg, HV_BINOP_SUBTRACT, 0, m, &cBinop_m7ZJ2kfg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_FN4IT242_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5vP9w80D, HV_BINOP_MAX, 0, m, &cBinop_5vP9w80D_sendMessage);
}

void Heavy_vSwell::cBinop_OfPzIDth_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FN4IT242, HV_BINOP_MULTIPLY, 0, m, &cBinop_FN4IT242_sendMessage);
}

void Heavy_vSwell::cBinop_p21IZPGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K2BDCjPj_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_mqqAdMNR, 0, m, &sTabread_mqqAdMNR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LMR2u7Tj_sendMessage);
}

void Heavy_vSwell::cSystem_mBNRYGgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m7ZJ2kfg, HV_BINOP_SUBTRACT, 1, m, &cBinop_m7ZJ2kfg_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NGVJghBN, 2, m, &cDelay_NGVJghBN_sendMessage);
}

void Heavy_vSwell::cMsg_hs6WArQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_mBNRYGgp_sendMessage);
}

void Heavy_vSwell::cMsg_K2BDCjPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZlPOquOz, 0, m, &cDelay_ZlPOquOz_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NGVJghBN, 0, m, &cDelay_NGVJghBN_sendMessage);
}

void Heavy_vSwell::cMsg_jP5Q935P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_5vP9w80D, HV_BINOP_MAX, 1, m, &cBinop_5vP9w80D_sendMessage);
}

void Heavy_vSwell::cBinop_5vP9w80D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p21IZPGu, HV_BINOP_SUBTRACT, 1, m, &cBinop_p21IZPGu_sendMessage);
}

void Heavy_vSwell::cCast_LMR2u7Tj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZlPOquOz, 0, m, &cDelay_ZlPOquOz_sendMessage);
}

void Heavy_vSwell::cBinop_lCNLuX1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZlPOquOz, 2, m, &cDelay_ZlPOquOz_sendMessage);
}

void Heavy_vSwell::cBinop_m7ZJ2kfg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_lCNLuX1j_sendMessage);
}

void Heavy_vSwell::cCast_3uTMbqhz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5VemrPRy, 0, m, &cVar_5VemrPRy_sendMessage);
  cMsg_5XdSssus_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_fwQWuPFc, 0, m, &cTabhead_fwQWuPFc_sendMessage);
}

void Heavy_vSwell::cUnop_VxDzO72P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_d0bikSMm, m);
}

void Heavy_vSwell::cCast_V0dwKiDY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NetDGfMy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_kWffPOzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_b9DeB9hE_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_nAL51q38, 0, m, &cVar_nAL51q38_sendMessage);
}

void Heavy_vSwell::cCast_tWARpdHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zPTfGL8p, HV_BINOP_SUBTRACT, 0, m, &cBinop_zPTfGL8p_sendMessage);
}

void Heavy_vSwell::cCast_0ZOUqlk2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZaWooGE1, 0, m, &cVar_ZaWooGE1_sendMessage);
}

void Heavy_vSwell::cBinop_zPTfGL8p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tOZysBtI, 0, m, &cVar_tOZysBtI_sendMessage);
}

void Heavy_vSwell::cSend_b9DeB9hE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SdCXEuUK_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_ZFt9jXEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_dII8J2No_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_31mA4tX7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 25.0f);
  cSwitchcase_xkLW81KQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_lXP1Kvxz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 3.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BezNSOW6, 0, m, NULL);
}

void Heavy_vSwell::cSend_oOC3cZGE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bYE7z1C9_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_ekSrRxC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_QsCxcNXl, 1, m, &cDelay_QsCxcNXl_sendMessage);
}

void Heavy_vSwell::cBinop_VsxUg45t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_VxDzO72P_sendMessage);
}

void Heavy_vSwell::cReceive_XOVOfYRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zPTfGL8p, HV_BINOP_SUBTRACT, 1, m, &cBinop_zPTfGL8p_sendMessage);
}

void Heavy_vSwell::cReceive_NndMLYGi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WJIVLqW9_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_GF8y1ABq, 0, m, &cVar_GF8y1ABq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AsQPnQUF, 0, m, &cVar_AsQPnQUF_sendMessage);
  cMsg_zQZs0CFc_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_LQdCofB3, 0, m, &cVar_LQdCofB3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Hn8Y9KG0, 0, m, &cVar_Hn8Y9KG0_sendMessage);
  cMsg_9j2ZHxoG_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ghIpJIpz, 0, m, &cVar_ghIpJIpz_sendMessage);
  cMsg_gPtTOCQF_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Ujqn5B4c, 0, m, &cVar_Ujqn5B4c_sendMessage);
  cMsg_jP5Q935P_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_5VemrPRy, 0, m, &cVar_5VemrPRy_sendMessage);
  cMsg_5XdSssus_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_fwQWuPFc, 0, m, &cTabhead_fwQWuPFc_sendMessage);
}

void Heavy_vSwell::cReceive_meGzIDpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSlice_onMessage(_c, &Context(_c)->cSlice_qRkKKr90, 0, m, &cSlice_qRkKKr90_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_7uiBNeIG, 0, m, &cSlice_7uiBNeIG_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_gOqcKDlb, 0, m, &cSlice_gOqcKDlb_sendMessage);
}

void Heavy_vSwell::cReceive_TM7Af2yn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_7I71UFmw, m);
}

void Heavy_vSwell::cReceive_SdCXEuUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pEaJJvXk_sendMessage(_c, 0, m);
  cMsg_yMQyPyYC_sendMessage(_c, 0, m);
  cMsg_3MaxPmlR_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cReceive_gGPOHLYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tWARpdHW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0ZOUqlk2_sendMessage);
}

void Heavy_vSwell::cReceive_xbN8j2Z0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kWffPOzr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V0dwKiDY_sendMessage);
}

void Heavy_vSwell::cReceive_K8OqLLmn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ENtuxI01, 1, m, &cIf_ENtuxI01_sendMessage);
}

void Heavy_vSwell::cReceive_NOaODW6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EQONWyXy, 1, m, &cVar_EQONWyXy_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_5hiHPDkp, 1, m, &cPack_5hiHPDkp_sendMessage);
}

void Heavy_vSwell::cReceive_q2GZA6cK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_5hiHPDkp, 2, m, &cPack_5hiHPDkp_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XEag6QEu, 1, m, &cDelay_XEag6QEu_sendMessage);
}

void Heavy_vSwell::cReceive_KASih03w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_VCQnPfRS, 1, m, &cPack_VCQnPfRS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9oMUutVY, 1, m, &cVar_9oMUutVY_sendMessage);
}

void Heavy_vSwell::cReceive_FNvI9UDj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_VCQnPfRS, 2, m, &cPack_VCQnPfRS_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AAudHFdI, 1, m, &cDelay_AAudHFdI_sendMessage);
}

void Heavy_vSwell::cReceive_c2hhDQQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_WyVZXNkK, 2, m, &cPack_WyVZXNkK_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_meuw9Wv3, 1, m, &cDelay_meuw9Wv3_sendMessage);
}

void Heavy_vSwell::cReceive_bYE7z1C9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ujqn5B4c, 1, m, &cVar_Ujqn5B4c_sendMessage);
  cMsg_31mA4tX7_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_nAL51q38, 1, m, &cVar_nAL51q38_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NvWXuOBw, 1, m, &cVar_NvWXuOBw_sendMessage);
}

void Heavy_vSwell::cReceive_mZxXXkrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oOC3cZGE_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cReceive_ag4G1gks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 3.0f, 0, m, &cBinop_ekSrRxC8_sendMessage);
}

void Heavy_vSwell::cReceive_XHZQBboD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_VsxUg45t_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_zAssTYCd, m);
}




/*
 * Context Process Implementation
 */

int Heavy_vSwell::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4;

  // input and output vars
  hv_bufferf_t O0;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));

    // process all signal functions
    __hv_tabwrite_f(&sTabwrite_8YX3EPBE, VIf(I0));
    __hv_tabread_f(&sTabread_mqqAdMNR, VOf(Bf0));
    __hv_varread_f(&sVarf_jmTHfqE8, VOf(Bf1));
    __hv_mul_f(VIf(I1), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_7LXMyjmW, VOf(Bf2));
    __hv_rpole_f(&sRPole_atEW7q7c, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_zAssTYCd, VOf(Bf1));
    __hv_varread_f(&sVarf_d0bikSMm, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf4), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_mul_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf3));
    __hv_gt_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_sqrt_f(VIf(Bf4), VOf(Bf4));
    __hv_and_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf3), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_div_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_snslWM2R, VIf(Bf3), &sEnv_snslWM2R_sendMessage);
    __hv_line_f(&sLine_BezNSOW6, VOf(Bf3));
    __hv_varread_f(&sVarf_7I71UFmw, VOf(Bf1));
    __hv_pow_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_fzlcNhf9, VOf(Bf3));
    __hv_max_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf1), 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f);
    __hv_min_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf1), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_vSwell::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 1 channel(s)
  float **const bOut = &outputBuffers;

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_vSwell::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 1 channel(s)
  float *const bOut = outputBuffers;

  int n = processInline(bIn, bOut, n4);

  

  return n;
}
