/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_VSWELL_HPP_
#define _HEAVY_CONTEXT_VSWELL_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalRPole.h"
#include "HvControlVar.h"
#include "HvControlDelay.h"
#include "HvControlTabhead.h"
#include "HvControlPack.h"
#include "HvControlSlice.h"
#include "HvControlUnop.h"
#include "HvSignalTabread.h"
#include "HvSignalVar.h"
#include "HvControlBinop.h"
#include "HvControlSystem.h"
#include "HvTable.h"
#include "HvControlCast.h"
#include "HvSignalEnvelope.h"
#include "HvSignalTabwrite.h"
#include "HvSignalDel1.h"
#include "HvMath.h"
#include "HvControlIf.h"
#include "HvSignalLine.h"

class Heavy_vSwell : public HeavyContext {

 public:
  Heavy_vSwell(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_vSwell();

  const char *getName() override { return "vSwell"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 1; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        ATTACK_LEVEL = 0xCFF35931, // Attack_Level
        ATTACK_MS = 0x4397AE0, // Attack_ms
        MID_LEVEL = 0x73ACB90E, // Mid_Level
        MID_MS = 0x4675584E, // Mid_ms
        RELEASE_MS = 0x558F437A, // Release_ms
        SHAPE = 0x8D204657, // Shape
        SUBENV_LEVEL = 0x2D669F6F, // SubEnv_Level
        THRESHOLD_HIGH = 0x7BABB594, // Threshold_High
        THRESHOLD_LOW = 0xA0E82E9F, // Threshold_Low
        THRESHOLD_STRICT = 0x145892E8, // Threshold_Strict
        TRIGGER_DELAY = 0xCB36B160, // Trigger_Delay
        TRIGGER_EXT = 0x5DF5B524, // Trigger_EXT
        TRIGGER_BY_AUDIO_ON = 0xE7A7BB75, // Trigger_by_Audio_ON
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void sEnv_snslWM2R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_EKSw34RE_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_jZPFs3Pa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_C3ruHQ1y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mAydGJYG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_q7TWCEnM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XQLGilYY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tKuwHdxt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5gTfgAg2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HAC9IFQU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2kmEJwJU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Y3mrz4RY_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_7VPbJHnd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_p1cq5hbv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XsG1XrFt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Mo0tyTfh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sSKxXYNc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_k9ShkCqA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nIzG9Bkq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rr864ZaP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Y8W6ghvP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_l5hurNa9_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_nkSBKHzA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ogrMB5EB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_7ADg6cnK_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_8j8a5npo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1yTwCkaM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZaWooGE1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_tOZysBtI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dfckWdhJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_68N4esNu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ibIBnrzf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O0by1yLp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_qRkKKr90_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_7uiBNeIG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_gOqcKDlb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AsQPnQUF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_rRguzkJr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Nor0BPcS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_kWK8ktFV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B1g7QHAA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_hlxHUpRv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_jhx1syLy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_5l7cExWi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_PniLnrmH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ug2IdYPJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lhNyZWVT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_enM2Xdga_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bZqVH9Dk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PuItF0QU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pjzqRHid_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RV7sxujL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TgCKJUWk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_lLXTi7jC_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_XEag6QEu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_neG5BynG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DzGYUOpD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_5hiHPDkp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NvWXuOBw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pEaJJvXk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8mtWZ8l5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uFAOkFy9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ebplqSfA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jNXjSiKl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_CNahkTwm_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_AAudHFdI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SFUwxmGw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rxxrxeQH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_VCQnPfRS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EQONWyXy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yMQyPyYC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_byFXRt5B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6W4KspOJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0bGQVjKO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UQeAYN9r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_VN7csrgs_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_meuw9Wv3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m2BrlF56_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1UU5wx8Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_WyVZXNkK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9oMUutVY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3MaxPmlR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_12Kp6Bk1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Bs1tJPm5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_i8WglQKq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ug9qGsx5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ENtuxI01_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_dII8J2No_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_sF2qRG37_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nAL51q38_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Ujqn5B4c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zQZs0CFc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_04NSgjIZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_L6cpp22J_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_ZIXAF6sI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BnC3cihC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WJIVLqW9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_C8boggNI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GF8y1ABq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8f7hku9h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3y4xF1sF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_chUnHbKP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HW3VoGZb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TJm0knBm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_9ALPtWEP_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_lA5THhH2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9FdGaS4V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_xkLW81KQ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_EqJAUSMY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_xnb3BmAC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1QgcpgdV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Hn8Y9KG0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_GtHEjGpj_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_DNu1VkFN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LQdCofB3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_g1HhU4T4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0VDNPViY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_lkCjiPC7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_mN7HjAVA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5zi7jhKJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gtuAQdnG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_l57OLQQT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B7lE7FJi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OS97a4Fb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bgYHVTFR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oeY6l5T6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oLzKdThs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DwYXyudI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s5WqOUBc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1QyrWd3l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lYvGXlJJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N9jYrVss_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IoxCGfhw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yzlk2eaX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zatomjpw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jO6M1MX0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mWd0Efth_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SLqj7Ms5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p336uaRl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_53GWacqN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0RnN6Qoi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Q8n1GQZd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_srWX1ZnE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_p6kzVR7b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ArXaKoNg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_25r7LSj5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_w2Ocfgbm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_NetDGfMy_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_QsCxcNXl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bgznUTdm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_B3cytmgu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ghIpJIpz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9j2ZHxoG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_dmUFjqR7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KwwBlsQa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_247Mb6jy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ruCXm1rD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Az2z5uJD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UiafoXw9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aPAbK9Sh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gPtTOCQF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Lmpvadnd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ZNEsC6u8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_UzhKvguc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_xnku7c2U_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_MgwwV9z5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_6m1i5BNE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DKh5VbwQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hzBcgxt5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yvn0ZH9b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gJsojgV2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gJxhuCX7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LePE19uZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_fwQWuPFc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5XdSssus_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_WocATEVP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5VemrPRy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ZlPOquOz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_NGVJghBN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_mqqAdMNR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FN4IT242_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OfPzIDth_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p21IZPGu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_mBNRYGgp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hs6WArQ2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K2BDCjPj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jP5Q935P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5vP9w80D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LMR2u7Tj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lCNLuX1j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m7ZJ2kfg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3uTMbqhz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_VxDzO72P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V0dwKiDY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kWffPOzr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tWARpdHW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0ZOUqlk2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zPTfGL8p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_b9DeB9hE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZFt9jXEk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_31mA4tX7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lXP1Kvxz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_oOC3cZGE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ekSrRxC8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VsxUg45t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_XOVOfYRX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_NndMLYGi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_meGzIDpH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TM7Af2yn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_SdCXEuUK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gGPOHLYc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xbN8j2Z0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_K8OqLLmn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_NOaODW6I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_q2GZA6cK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KASih03w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FNvI9UDj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_c2hhDQQI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bYE7z1C9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_mZxXXkrP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ag4G1gks_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_XHZQBboD_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalTabwrite sTabwrite_8YX3EPBE;
  SignalTabread sTabread_mqqAdMNR;
  SignalRPole sRPole_atEW7q7c;
  SignalEnvelope sEnv_snslWM2R;
  SignalLine sLine_BezNSOW6;
  ControlSlice cSlice_jZPFs3Pa;
  ControlSlice cSlice_C3ruHQ1y;
  ControlVar cVar_mAydGJYG;
  ControlIf cIf_q7TWCEnM;
  ControlBinop cBinop_5gTfgAg2;
  ControlSlice cSlice_7VPbJHnd;
  ControlSlice cSlice_p1cq5hbv;
  ControlVar cVar_XsG1XrFt;
  ControlIf cIf_Mo0tyTfh;
  ControlBinop cBinop_nIzG9Bkq;
  ControlVar cVar_ZaWooGE1;
  ControlVar cVar_tOZysBtI;
  ControlBinop cBinop_dfckWdhJ;
  ControlBinop cBinop_68N4esNu;
  ControlSlice cSlice_qRkKKr90;
  ControlSlice cSlice_7uiBNeIG;
  ControlSlice cSlice_gOqcKDlb;
  ControlVar cVar_AsQPnQUF;
  ControlIf cIf_kWK8ktFV;
  ControlBinop cBinop_B1g7QHAA;
  ControlIf cIf_hlxHUpRv;
  ControlIf cIf_jhx1syLy;
  ControlIf cIf_5l7cExWi;
  ControlIf cIf_PniLnrmH;
  ControlBinop cBinop_ug2IdYPJ;
  ControlBinop cBinop_lhNyZWVT;
  ControlBinop cBinop_enM2Xdga;
  ControlBinop cBinop_TgCKJUWk;
  ControlDelay cDelay_XEag6QEu;
  ControlPack cPack_5hiHPDkp;
  ControlVar cVar_NvWXuOBw;
  ControlDelay cDelay_AAudHFdI;
  ControlPack cPack_VCQnPfRS;
  ControlVar cVar_EQONWyXy;
  ControlDelay cDelay_meuw9Wv3;
  ControlPack cPack_WyVZXNkK;
  ControlVar cVar_9oMUutVY;
  ControlIf cIf_ENtuxI01;
  ControlVar cVar_nAL51q38;
  ControlVar cVar_Ujqn5B4c;
  SignalVarf sVarf_fzlcNhf9;
  ControlDelay cDelay_ZIXAF6sI;
  ControlVar cVar_GF8y1ABq;
  ControlBinop cBinop_3y4xF1sF;
  ControlBinop cBinop_chUnHbKP;
  ControlBinop cBinop_HW3VoGZb;
  ControlVar cVar_TJm0knBm;
  ControlSlice cSlice_EqJAUSMY;
  ControlSlice cSlice_xnb3BmAC;
  ControlVar cVar_1QgcpgdV;
  ControlVar cVar_Hn8Y9KG0;
  ControlVar cVar_LQdCofB3;
  ControlVar cVar_g1HhU4T4;
  ControlVar cVar_0VDNPViY;
  ControlSlice cSlice_lkCjiPC7;
  ControlSlice cSlice_mN7HjAVA;
  ControlBinop cBinop_5zi7jhKJ;
  ControlBinop cBinop_gtuAQdnG;
  ControlBinop cBinop_l57OLQQT;
  ControlBinop cBinop_B7lE7FJi;
  ControlBinop cBinop_OS97a4Fb;
  ControlBinop cBinop_oLzKdThs;
  ControlBinop cBinop_DwYXyudI;
  ControlBinop cBinop_s5WqOUBc;
  ControlBinop cBinop_1QyrWd3l;
  ControlBinop cBinop_mWd0Efth;
  ControlBinop cBinop_srWX1ZnE;
  ControlDelay cDelay_QsCxcNXl;
  ControlVar cVar_ghIpJIpz;
  ControlBinop cBinop_KwwBlsQa;
  ControlBinop cBinop_247Mb6jy;
  SignalVarf sVarf_7LXMyjmW;
  ControlBinop cBinop_Az2z5uJD;
  ControlBinop cBinop_UiafoXw9;
  ControlBinop cBinop_aPAbK9Sh;
  SignalVarf sVarf_jmTHfqE8;
  ControlDelay cDelay_ZNEsC6u8;
  ControlDelay cDelay_UzhKvguc;
  ControlBinop cBinop_MgwwV9z5;
  HvTable hTable_6m1i5BNE;
  ControlBinop cBinop_hzBcgxt5;
  ControlTabhead cTabhead_fwQWuPFc;
  ControlVar cVar_5VemrPRy;
  ControlDelay cDelay_ZlPOquOz;
  ControlDelay cDelay_NGVJghBN;
  ControlBinop cBinop_FN4IT242;
  ControlBinop cBinop_OfPzIDth;
  ControlBinop cBinop_p21IZPGu;
  ControlBinop cBinop_5vP9w80D;
  ControlBinop cBinop_lCNLuX1j;
  ControlBinop cBinop_m7ZJ2kfg;
  ControlBinop cBinop_zPTfGL8p;
  ControlBinop cBinop_ZFt9jXEk;
  ControlBinop cBinop_ekSrRxC8;
  ControlBinop cBinop_VsxUg45t;
  SignalVarf sVarf_7I71UFmw;
  SignalVarf sVarf_d0bikSMm;
  SignalVarf sVarf_zAssTYCd;
};

#endif // _HEAVY_CONTEXT_VSWELL_HPP_
