/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_vSwellST.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_vSwellST *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_vSwellST_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwellST));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwellST(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_vSwellST_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwellST));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwellST(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_vSwellST_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_vSwellST();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_vSwellST::Heavy_vSwellST(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sTabwrite_init(&sTabwrite_j1CIUJDo, &hTable_2GB6yxxw);
  numBytes += sTabwrite_init(&sTabwrite_N1fYoRVV, &hTable_sZIntTQa);
  numBytes += sRPole_init(&sRPole_IXWYN6yt);
  numBytes += sEnv_init(&sEnv_KYqzSBK1, 1024, 512);
  numBytes += sTabread_init(&sTabread_3ewLDZRo, &hTable_sZIntTQa, true);
  numBytes += sLine_init(&sLine_bwrYCOTk);
  numBytes += sTabread_init(&sTabread_I0P2Mz6T, &hTable_2GB6yxxw, true);
  numBytes += cSlice_init(&cSlice_kUsIvDYb, 1, -1);
  numBytes += cSlice_init(&cSlice_Ymt457hZ, 1, -1);
  numBytes += cVar_init_f(&cVar_ZmkMeviw, 0.0f);
  numBytes += cIf_init(&cIf_6IGIQnSW, false);
  numBytes += cBinop_init(&cBinop_5nKaYhnl, 0.0f); // __neq
  numBytes += cSlice_init(&cSlice_zQMP3oZY, 1, -1);
  numBytes += cSlice_init(&cSlice_xkVE3V0n, 1, -1);
  numBytes += cVar_init_f(&cVar_UK3NEzr3, 0.0f);
  numBytes += cIf_init(&cIf_GT4G7csp, false);
  numBytes += cBinop_init(&cBinop_IO3qDjUu, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_ZGcsbFHz, 0.0f);
  numBytes += cVar_init_f(&cVar_Z7MFt3HX, 0.0f);
  numBytes += cBinop_init(&cBinop_HwrEeF2d, 0.0f); // __gt
  numBytes += cBinop_init(&cBinop_mRa69i1T, 0.0f); // __lt
  numBytes += cSlice_init(&cSlice_wlQYKdRs, 2, 1);
  numBytes += cSlice_init(&cSlice_Zo2Rhipc, 1, 1);
  numBytes += cSlice_init(&cSlice_P16TrA7Z, 0, 1);
  numBytes += cVar_init_f(&cVar_kkUcmFIg, 0.0f);
  numBytes += cIf_init(&cIf_RfA4GWQj, false);
  numBytes += cIf_init(&cIf_BfvfQnyV, false);
  numBytes += cIf_init(&cIf_WoMY3zTr, false);
  numBytes += cIf_init(&cIf_3H8MbAcW, false);
  numBytes += cIf_init(&cIf_Pqcbd7Is, false);
  numBytes += cBinop_init(&cBinop_P6KZwdpr, 0.0f); // __eq
  numBytes += cDelay_init(this, &cDelay_am5Z1eoa, 10.0f);
  numBytes += cPack_init(&cPack_Sh5iiyiX, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_QEtqqzJj, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_VMo3SjkN, 10.0f);
  numBytes += cPack_init(&cPack_1I5x3qnT, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_ObP4Qio3, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_p0MVtv2R, 10.0f);
  numBytes += cPack_init(&cPack_nCoaqy6k, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_gbskxB5t, 1e-07f);
  numBytes += cVar_init_f(&cVar_Yb8FRUaf, 1e-07f);
  numBytes += cVar_init_f(&cVar_KyJbcFpu, 1e-07f);
  numBytes += sVarf_init(&sVarf_HoSFLJRe, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_tpmZPgsD, 0.0f);
  numBytes += cVar_init_f(&cVar_uCWQdVCF, 20.0f);
  numBytes += cBinop_init(&cBinop_ywQh6Pvk, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_eiZzYgbq, 0.0f);
  numBytes += cSlice_init(&cSlice_bqRkZPHa, 1, -1);
  numBytes += cSlice_init(&cSlice_phYRUGJM, 1, -1);
  numBytes += cVar_init_f(&cVar_TzTxvCTS, 0.0f);
  numBytes += cVar_init_f(&cVar_Bgp5HMXz, 20.0f);
  numBytes += cVar_init_f(&cVar_aqKYmkLt, 0.0f);
  numBytes += cVar_init_f(&cVar_T4b66XsC, 0.0f);
  numBytes += cVar_init_f(&cVar_voZ9RdYK, 0.0f);
  numBytes += cSlice_init(&cSlice_GwtEzfP9, 1, 1);
  numBytes += cSlice_init(&cSlice_W6Dp6ub4, 0, 1);
  numBytes += cBinop_init(&cBinop_J5WOijBI, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AuFgRGl7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_izqO1xZu, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_xFR5iLZR, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_EXHg3tMu, 20.0f); // __div
  numBytes += cBinop_init(&cBinop_CH1lcZTe, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_8jHfQ2MZ, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_MY96kkHS, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_V7tYoziN, 5.0f);
  numBytes += cVar_init_f(&cVar_IkUoPbGA, 500.0f);
  numBytes += cBinop_init(&cBinop_OdvKNlxk, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_fuWTIfNs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Oa4sqCzD, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_nlbUy3IG, 0.0f);
  numBytes += cDelay_init(this, &cDelay_9un7sDVD, 0.0f);
  numBytes += hTable_init(&hTable_2GB6yxxw, 256);
  numBytes += cTabhead_init(&cTabhead_PUvqYa8B, &hTable_2GB6yxxw);
  numBytes += cVar_init_s(&cVar_HonAkLRB, "del-1001-swell");
  numBytes += cDelay_init(this, &cDelay_BtbFu6cI, 8.0f);
  numBytes += cDelay_init(this, &cDelay_W0mJADVI, 0.0f);
  numBytes += cBinop_init(&cBinop_VMGQmFtc, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_69DBDI33, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_l0UPWi3w, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_N8MUtGKb, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_eOzhrXbw, 0.0f);
  numBytes += cDelay_init(this, &cDelay_V2EQm0d9, 0.0f);
  numBytes += hTable_init(&hTable_sZIntTQa, 256);
  numBytes += cTabhead_init(&cTabhead_4zv4I59K, &hTable_sZIntTQa);
  numBytes += cVar_init_s(&cVar_Z3deqqQQ, "del-1001-swell2");
  numBytes += cDelay_init(this, &cDelay_E3MVlhOV, 8.0f);
  numBytes += cDelay_init(this, &cDelay_FOUyjeGS, 0.0f);
  numBytes += cBinop_init(&cBinop_NAqOND6g, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_KVcMBn7F, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_9A18FjG0, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_r2Tik4xx, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_ZuGnLBEo, 2.0f); // __sub
  numBytes += sVarf_init(&sVarf_VWOZeBDH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CsQvDf7O, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fg2c2OPa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GxwLKfXu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bTXg0p4V, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_vSwellST::~Heavy_vSwellST() {
  sEnv_free(&sEnv_KYqzSBK1);
  cPack_free(&cPack_Sh5iiyiX);
  cPack_free(&cPack_1I5x3qnT);
  cPack_free(&cPack_nCoaqy6k);
  hTable_free(&hTable_2GB6yxxw);
  hTable_free(&hTable_sZIntTQa);
}

HvTable *Heavy_vSwellST::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xB4039215: return &hTable_2GB6yxxw; // del-1001-swell
    case 0x505A9C79: return &hTable_sZIntTQa; // del-1001-swell2
    default: return nullptr;
  }
}

void Heavy_vSwellST::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xCFF35931: { // Attack_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OnGDgJ4Z_sendMessage);
      break;
    }
    case 0x4397AE0: { // Attack_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VCUiqBsQ_sendMessage);
      break;
    }
    case 0x73ACB90E: { // Mid_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_s2hhY4Fa_sendMessage);
      break;
    }
    case 0x4675584E: { // Mid_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vNa01IX8_sendMessage);
      break;
    }
    case 0x558F437A: { // Release_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_J2igMN5p_sendMessage);
      break;
    }
    case 0x8D204657: { // Shape
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zcsOypYA_sendMessage);
      break;
    }
    case 0x2D669F6F: { // SubEnv_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_i8NEW1R3_sendMessage);
      break;
    }
    case 0x7BABB594: { // Threshold_High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bLgp72MA_sendMessage);
      break;
    }
    case 0xA0E82E9F: { // Threshold_Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uU3P15qo_sendMessage);
      break;
    }
    case 0x145892E8: { // Threshold_Strict
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BcTjIa7S_sendMessage);
      break;
    }
    case 0xCB36B160: { // Trigger_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aNRFKlmP_sendMessage);
      break;
    }
    case 0x5DF5B524: { // Trigger_EXT
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7vcl7qqh_sendMessage);
      break;
    }
    case 0x4E6E7C40: { // Trigger_Left
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oi7aVQcc_sendMessage);
      break;
    }
    case 0xB181ABB6: { // Trigger_Right
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_htFf6a5M_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0QPxbHMo_sendMessage);
      break;
    }
    case 0x67E37CA3: { // __hv_notein
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_k2XaLLMa_sendMessage);
      break;
    }
    case 0xA2F0F2D3: { // ecancel
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_idFjLCAi_sendMessage);
      break;
    }
    case 0xC698CFF8: { // subenv
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_arjXBc33_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_vSwellST::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Attack_Level";
        info->hash = 0xCFF35931;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.6f;
        break;
      }
      case 1: {
        info->name = "Attack_ms";
        info->hash = 0x4397AE0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 3000.0f;
        info->defaultVal = 400.0f;
        break;
      }
      case 2: {
        info->name = "Mid_Level";
        info->hash = 0x73ACB90E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.65f;
        break;
      }
      case 3: {
        info->name = "Mid_ms";
        info->hash = 0x4675584E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 4: {
        info->name = "Release_ms";
        info->hash = 0x558F437A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 2200.0f;
        break;
      }
      case 5: {
        info->name = "Shape";
        info->hash = 0x8D204657;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.1f;
        info->maxVal = 3.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 6: {
        info->name = "SubEnv_Level";
        info->hash = 0x2D669F6F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1e-07f;
        info->maxVal = 0.7f;
        info->defaultVal = 1e-07f;
        break;
      }
      case 7: {
        info->name = "Threshold_High";
        info->hash = 0x7BABB594;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 20.0f;
        info->maxVal = 90.0f;
        info->defaultVal = 52.0f;
        break;
      }
      case 8: {
        info->name = "Threshold_Low";
        info->hash = 0xA0E82E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.3f;
        info->maxVal = 8.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 9: {
        info->name = "Threshold_Strict";
        info->hash = 0x145892E8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "Trigger_Delay";
        info->hash = 0xCB36B160;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 50.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 11: {
        info->name = "Trigger_EXT";
        info->hash = 0x5DF5B524;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Trigger_Left";
        info->hash = 0x4E6E7C40;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "Trigger_Right";
        info->hash = 0xB181ABB6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 14;
}



/*
 * Send Function Implementations
 */


void Heavy_vSwellST::sEnv_KYqzSBK1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HwrEeF2d, HV_BINOP_GREATER_THAN, 0, m, &cBinop_HwrEeF2d_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mRa69i1T, HV_BINOP_LESS_THAN, 0, m, &cBinop_mRa69i1T_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_4dIJTwo2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_kUsIvDYb, 0, m, &cSlice_kUsIvDYb_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Ymt457hZ, 0, m, &cSlice_Ymt457hZ_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D5i7VEJr_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mIQ4Qsds_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_kUsIvDYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_ZmkMeviw, 0, m, &cVar_ZmkMeviw_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_ZmkMeviw, 0, m, &cVar_ZmkMeviw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_Ymt457hZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_5nKaYhnl, HV_BINOP_NEQ, 1, m, &cBinop_5nKaYhnl_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_ZmkMeviw, 1, m, &cVar_ZmkMeviw_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_5nKaYhnl, HV_BINOP_NEQ, 1, m, &cBinop_5nKaYhnl_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_ZmkMeviw, 1, m, &cVar_ZmkMeviw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_ZmkMeviw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_LIxG5f6G_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cIf_6IGIQnSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7WS47zez_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6tpvPVNA_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cCast_6tpvPVNA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZmkMeviw, 0, m, &cVar_ZmkMeviw_sendMessage);
}

void Heavy_vSwellST::cCast_7WS47zez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5nKaYhnl, HV_BINOP_NEQ, 1, m, &cBinop_5nKaYhnl_sendMessage);
}

void Heavy_vSwellST::cBinop_5nKaYhnl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6IGIQnSW, 1, m, &cIf_6IGIQnSW_sendMessage);
}

void Heavy_vSwellST::cCast_D5i7VEJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5nKaYhnl, HV_BINOP_NEQ, 0, m, &cBinop_5nKaYhnl_sendMessage);
}

void Heavy_vSwellST::cCast_mIQ4Qsds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6IGIQnSW, 0, m, &cIf_6IGIQnSW_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_3HzM9i9Q_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zQMP3oZY, 0, m, &cSlice_zQMP3oZY_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xkVE3V0n, 0, m, &cSlice_xkVE3V0n_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BpAjvMfZ_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gdoA3WuY_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_zQMP3oZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_UK3NEzr3, 0, m, &cVar_UK3NEzr3_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_UK3NEzr3, 0, m, &cVar_UK3NEzr3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_xkVE3V0n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_IO3qDjUu, HV_BINOP_NEQ, 1, m, &cBinop_IO3qDjUu_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_UK3NEzr3, 1, m, &cVar_UK3NEzr3_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_IO3qDjUu, HV_BINOP_NEQ, 1, m, &cBinop_IO3qDjUu_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_UK3NEzr3, 1, m, &cVar_UK3NEzr3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_UK3NEzr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_P1ao0gKl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cIf_GT4G7csp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Tbb3lmpv_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EKaVJZ1j_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cCast_Tbb3lmpv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IO3qDjUu, HV_BINOP_NEQ, 1, m, &cBinop_IO3qDjUu_sendMessage);
}

void Heavy_vSwellST::cCast_EKaVJZ1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UK3NEzr3, 0, m, &cVar_UK3NEzr3_sendMessage);
}

void Heavy_vSwellST::cBinop_IO3qDjUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GT4G7csp, 1, m, &cIf_GT4G7csp_sendMessage);
}

void Heavy_vSwellST::cCast_BpAjvMfZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IO3qDjUu, HV_BINOP_NEQ, 0, m, &cBinop_IO3qDjUu_sendMessage);
}

void Heavy_vSwellST::cCast_gdoA3WuY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GT4G7csp, 0, m, &cIf_GT4G7csp_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_LIxG5f6G_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YsdepIbw_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jckertfo_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_YsdepIbw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Z7MFt3HX, 0, m, &cVar_Z7MFt3HX_sendMessage);
}

void Heavy_vSwellST::cCast_jckertfo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a1BcItA9_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_npxe7XIK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LiEL1CNC_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_P1ao0gKl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FoExB7X5_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BkUQpZnt_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_FoExB7X5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZGcsbFHz, 0, m, &cVar_ZGcsbFHz_sendMessage);
}

void Heavy_vSwellST::cCast_BkUQpZnt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rAkVL9El_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_ZGcsbFHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HwrEeF2d, HV_BINOP_GREATER_THAN, 1, m, &cBinop_HwrEeF2d_sendMessage);
}

void Heavy_vSwellST::cVar_Z7MFt3HX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mRa69i1T, HV_BINOP_LESS_THAN, 1, m, &cBinop_mRa69i1T_sendMessage);
}

void Heavy_vSwellST::cBinop_HwrEeF2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4dIJTwo2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cBinop_mRa69i1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3HzM9i9Q_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_a1BcItA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HwrEeF2d, HV_BINOP_GREATER_THAN, 1, m, &cBinop_HwrEeF2d_sendMessage);
}

void Heavy_vSwellST::cMsg_rAkVL9El_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, -1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mRa69i1T, HV_BINOP_LESS_THAN, 1, m, &cBinop_mRa69i1T_sendMessage);
}

void Heavy_vSwellST::cSlice_wlQYKdRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_PkR58g3y_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_Zo2Rhipc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_3H8MbAcW, 0, m, &cIf_3H8MbAcW_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_BfvfQnyV, 0, m, &cIf_BfvfQnyV_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_P16TrA7Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_Pqcbd7Is, 0, m, &cIf_Pqcbd7Is_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_WoMY3zTr, 0, m, &cIf_WoMY3zTr_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_kkUcmFIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_cQYm8zan_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_RfA4GWQj, 0, m, &cIf_RfA4GWQj_sendMessage);
}

void Heavy_vSwellST::cUnop_EIpUqWTD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9rhfxANs_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_P6KZwdpr, HV_BINOP_EQ, 1, m, &cBinop_P6KZwdpr_sendMessage);
}

void Heavy_vSwellST::cUnop_YDljjyra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9rhfxANs_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_P6KZwdpr, HV_BINOP_EQ, 1, m, &cBinop_P6KZwdpr_sendMessage);
}

void Heavy_vSwellST::cIf_RfA4GWQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_YDljjyra_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_EIpUqWTD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_cQYm8zan_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RfA4GWQj, 1, m, &cIf_RfA4GWQj_sendMessage);
}

void Heavy_vSwellST::cIf_BfvfQnyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_DELjWDJO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_WoMY3zTr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_3H8MbAcW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_DELjWDJO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_Pqcbd7Is_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_PkR58g3y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P6KZwdpr, HV_BINOP_EQ, 0, m, &cBinop_P6KZwdpr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_4eKeAMaO_sendMessage);
}

void Heavy_vSwellST::cBinop_9rhfxANs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2FU5w0tr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IPbtG8h7_sendMessage);
}

void Heavy_vSwellST::cBinop_P6KZwdpr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AKCN3yk0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XeRijmgP_sendMessage);
}

void Heavy_vSwellST::cCast_XeRijmgP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Pqcbd7Is, 1, m, &cIf_Pqcbd7Is_sendMessage);
}

void Heavy_vSwellST::cCast_AKCN3yk0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BfvfQnyV, 1, m, &cIf_BfvfQnyV_sendMessage);
}

void Heavy_vSwellST::cCast_IPbtG8h7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WoMY3zTr, 1, m, &cIf_WoMY3zTr_sendMessage);
}

void Heavy_vSwellST::cCast_2FU5w0tr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3H8MbAcW, 1, m, &cIf_3H8MbAcW_sendMessage);
}

void Heavy_vSwellST::cBinop_4eKeAMaO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_vSwellST::cSwitchcase_aTYlyQeg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_109l0JOm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_109l0JOm_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_am5Z1eoa, 1, m, &cDelay_am5Z1eoa_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DlkEVMkG_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_am5Z1eoa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_am5Z1eoa, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1ZTPLdfn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fsYW8ok1_sendMessage);
  cSwitchcase_PJNHKYSp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_109l0JOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_am5Z1eoa, 0, m, &cDelay_am5Z1eoa_sendMessage);
}

void Heavy_vSwellST::cCast_DlkEVMkG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_am5Z1eoa, 0, m, &cDelay_am5Z1eoa_sendMessage);
}

void Heavy_vSwellST::cPack_Sh5iiyiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O5POlD0O_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_QEtqqzJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Db3pssJs_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_jOAp28AW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_aTYlyQeg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_jZIojUsY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_Sh5iiyiX, 0, m, &cPack_Sh5iiyiX_sendMessage);
}

void Heavy_vSwellST::cCast_eCPG84Ls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QEtqqzJj, 0, m, &cVar_QEtqqzJj_sendMessage);
}

void Heavy_vSwellST::cMsg_Db3pssJs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_bwrYCOTk, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_O5POlD0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_bwrYCOTk, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_PJNHKYSp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_F9uD42R5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_F9uD42R5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_VMo3SjkN, 1, m, &cDelay_VMo3SjkN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KInwcSJk_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_VMo3SjkN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VMo3SjkN, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M0q3z2iJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1i1lUS7C_sendMessage);
  cSwitchcase_fTIcYPXn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_F9uD42R5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_VMo3SjkN, 0, m, &cDelay_VMo3SjkN_sendMessage);
}

void Heavy_vSwellST::cCast_KInwcSJk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VMo3SjkN, 0, m, &cDelay_VMo3SjkN_sendMessage);
}

void Heavy_vSwellST::cPack_1I5x3qnT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JkmV22eJ_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_ObP4Qio3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Omb0Mf8B_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_5YYh9Q6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_PJNHKYSp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_fsYW8ok1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_1I5x3qnT, 0, m, &cPack_1I5x3qnT_sendMessage);
}

void Heavy_vSwellST::cCast_1ZTPLdfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ObP4Qio3, 0, m, &cVar_ObP4Qio3_sendMessage);
}

void Heavy_vSwellST::cMsg_Omb0Mf8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_bwrYCOTk, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_JkmV22eJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_bwrYCOTk, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_fTIcYPXn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_PYRpD43v_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_PYRpD43v_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_p0MVtv2R, 1, m, &cDelay_p0MVtv2R_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rRaVS59Y_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_p0MVtv2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_p0MVtv2R, m);
}

void Heavy_vSwellST::cMsg_PYRpD43v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_p0MVtv2R, 0, m, &cDelay_p0MVtv2R_sendMessage);
}

void Heavy_vSwellST::cCast_rRaVS59Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_p0MVtv2R, 0, m, &cDelay_p0MVtv2R_sendMessage);
}

void Heavy_vSwellST::cPack_nCoaqy6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XQVJYPTM_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_gbskxB5t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Wr9ATiPN_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_zPv1oV7r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_fTIcYPXn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_M0q3z2iJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gbskxB5t, 0, m, &cVar_gbskxB5t_sendMessage);
}

void Heavy_vSwellST::cCast_1i1lUS7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_nCoaqy6k, 0, m, &cPack_nCoaqy6k_sendMessage);
}

void Heavy_vSwellST::cMsg_Wr9ATiPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_bwrYCOTk, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_XQVJYPTM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_bwrYCOTk, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_TPflp504_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9UWOtESQ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_9UWOtESQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_npxe7XIK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LiEL1CNC_sendMessage);
}

void Heavy_vSwellST::cVar_Yb8FRUaf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x6ss4zqG_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_KyJbcFpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_nCoaqy6k, 1, m, &cPack_nCoaqy6k_sendMessage);
}

void Heavy_vSwellST::cMsg_edjHny9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_f8KL77AI_sendMessage);
}

void Heavy_vSwellST::cSystem_f8KL77AI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AuFgRGl7, HV_BINOP_MULTIPLY, 1, m, &cBinop_AuFgRGl7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_J5WOijBI, HV_BINOP_MULTIPLY, 1, m, &cBinop_J5WOijBI_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_HEMITfPT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_hlBMrxzt_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_hlBMrxzt_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RaB2hj32_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_tpmZPgsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tpmZPgsD, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tpmZPgsD, 0, m, &cDelay_tpmZPgsD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_eiZzYgbq, 0, m, &cVar_eiZzYgbq_sendMessage);
}

void Heavy_vSwellST::cCast_RaB2hj32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hlBMrxzt_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tpmZPgsD, 0, m, &cDelay_tpmZPgsD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_eiZzYgbq, 0, m, &cVar_eiZzYgbq_sendMessage);
}

void Heavy_vSwellST::cMsg_7Pe0Fjx2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sbX5AdrU_sendMessage);
}

void Heavy_vSwellST::cSystem_sbX5AdrU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_IcXHbkvV_sendMessage);
}

void Heavy_vSwellST::cVar_uCWQdVCF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ywQh6Pvk, HV_BINOP_MULTIPLY, 0, m, &cBinop_ywQh6Pvk_sendMessage);
}

void Heavy_vSwellST::cMsg_hlBMrxzt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tpmZPgsD, 0, m, &cDelay_tpmZPgsD_sendMessage);
}

void Heavy_vSwellST::cBinop_vmgAQlWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tpmZPgsD, 2, m, &cDelay_tpmZPgsD_sendMessage);
}

void Heavy_vSwellST::cBinop_IcXHbkvV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ywQh6Pvk, HV_BINOP_MULTIPLY, 1, m, &cBinop_ywQh6Pvk_sendMessage);
}

void Heavy_vSwellST::cBinop_ywQh6Pvk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_vmgAQlWi_sendMessage);
}

void Heavy_vSwellST::cVar_eiZzYgbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_izqO1xZu, HV_BINOP_SUBTRACT, 0, m, &cBinop_izqO1xZu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_LESS_THAN_EQL, 0.0f, 0, m, &cBinop_nWyPTtFH_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_odXb0g8N_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OqDWVPQz_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XCYas3Ub_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_OqDWVPQz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_voZ9RdYK, 0, m, &cVar_voZ9RdYK_sendMessage);
}

void Heavy_vSwellST::cCast_XCYas3Ub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RlsL4rsg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iCPfI3Ho_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_5D6OwyNt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bqRkZPHa, 0, m, &cSlice_bqRkZPHa_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_phYRUGJM, 0, m, &cSlice_phYRUGJM_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Fb7v1Jof_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_GwtEzfP9, 0, m, &cSlice_GwtEzfP9_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_W6Dp6ub4, 0, m, &cSlice_W6Dp6ub4_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NIXU3Nn7_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hy1SAzLQ_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_bqRkZPHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_zCPTTDrw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cMsg_zCPTTDrw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_phYRUGJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LQxtcGHL_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LhF5Firr_sendMessage);
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LQxtcGHL_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LhF5Firr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_TzTxvCTS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gnpXa34O_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bi8b92lz_sendMessage);
}

void Heavy_vSwellST::cVar_Bgp5HMXz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_sV0U7uvu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_sV0U7uvu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tZXAdLXS_sendMessage);
      break;
    }
    default: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_AuFgRGl7, HV_BINOP_MULTIPLY, 0, m, &cBinop_AuFgRGl7_sendMessage);
      cBinop_onMessage(_c, &Context(_c)->cBinop_EXHg3tMu, HV_BINOP_DIVIDE, 1, m, &cBinop_EXHg3tMu_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_uCWQdVCF, 0, m, &cVar_uCWQdVCF_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cCast_tZXAdLXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xcHFjkjw_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_aqKYmkLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MY96kkHS, HV_BINOP_SUBTRACT, 1, m, &cBinop_MY96kkHS_sendMessage);
}

void Heavy_vSwellST::cVar_T4b66XsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_voZ9RdYK, 0, m, &cVar_voZ9RdYK_sendMessage);
}

void Heavy_vSwellST::cVar_voZ9RdYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xFR5iLZR, HV_BINOP_ADD, 0, m, &cBinop_xFR5iLZR_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8jHfQ2MZ, HV_BINOP_ADD, 0, m, &cBinop_8jHfQ2MZ_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_HoSFLJRe, m);
}

void Heavy_vSwellST::cSlice_GwtEzfP9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gnpXa34O_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bi8b92lz_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_W6Dp6ub4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mbRQkDJB_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0qDTa5wx_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_FipTWYTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eiZzYgbq, 1, m, &cVar_eiZzYgbq_sendMessage);
}

void Heavy_vSwellST::cBinop_J5WOijBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_FipTWYTb_sendMessage);
}

void Heavy_vSwellST::cBinop_AuFgRGl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qzLzcXzt_sendMessage);
}

void Heavy_vSwellST::cBinop_qzLzcXzt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_izqO1xZu, HV_BINOP_SUBTRACT, 1, m, &cBinop_izqO1xZu_sendMessage);
}

void Heavy_vSwellST::cBinop_izqO1xZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eiZzYgbq, 1, m, &cVar_eiZzYgbq_sendMessage);
}

void Heavy_vSwellST::cMsg_t8uZeee0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cSwitchcase_HEMITfPT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_UjDJ1fHp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_HEMITfPT_onMessage(_c, NULL, 0, m, NULL);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8jHfQ2MZ, HV_BINOP_ADD, 1, m, &cBinop_8jHfQ2MZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xFR5iLZR, HV_BINOP_ADD, 1, m, &cBinop_xFR5iLZR_sendMessage);
}

void Heavy_vSwellST::cBinop_nWyPTtFH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_odXb0g8N_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cBinop_xFR5iLZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_voZ9RdYK, 1, m, &cVar_voZ9RdYK_sendMessage);
}

void Heavy_vSwellST::cBinop_EXHg3tMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CH1lcZTe, HV_BINOP_DIVIDE, 1, m, &cBinop_CH1lcZTe_sendMessage);
}

void Heavy_vSwellST::cBinop_CH1lcZTe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8jHfQ2MZ, HV_BINOP_ADD, 1, m, &cBinop_8jHfQ2MZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xFR5iLZR, HV_BINOP_ADD, 1, m, &cBinop_xFR5iLZR_sendMessage);
}

void Heavy_vSwellST::cCast_bi8b92lz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EXHg3tMu, HV_BINOP_DIVIDE, 0, m, &cBinop_EXHg3tMu_sendMessage);
}

void Heavy_vSwellST::cCast_gnpXa34O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J5WOijBI, HV_BINOP_MULTIPLY, 0, m, &cBinop_J5WOijBI_sendMessage);
}

void Heavy_vSwellST::cCast_0qDTa5wx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MY96kkHS, HV_BINOP_SUBTRACT, 0, m, &cBinop_MY96kkHS_sendMessage);
}

void Heavy_vSwellST::cCast_mbRQkDJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_T4b66XsC, 1, m, &cVar_T4b66XsC_sendMessage);
}

void Heavy_vSwellST::cCast_iCPfI3Ho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_T4b66XsC, 0, m, &cVar_T4b66XsC_sendMessage);
}

void Heavy_vSwellST::cCast_RlsL4rsg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UjDJ1fHp_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_8jHfQ2MZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aqKYmkLt, 0, m, &cVar_aqKYmkLt_sendMessage);
}

void Heavy_vSwellST::cMsg_zCPTTDrw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_HEMITfPT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_QruafNEq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_TzTxvCTS, 1, m, &cVar_TzTxvCTS_sendMessage);
}

void Heavy_vSwellST::cMsg_xcHFjkjw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 20.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AuFgRGl7, HV_BINOP_MULTIPLY, 0, m, &cBinop_AuFgRGl7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EXHg3tMu, HV_BINOP_DIVIDE, 1, m, &cBinop_EXHg3tMu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uCWQdVCF, 0, m, &cVar_uCWQdVCF_sendMessage);
}

void Heavy_vSwellST::cCast_LhF5Firr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_heU0eX6W_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8jHfQ2MZ, HV_BINOP_ADD, 0, m, &cBinop_8jHfQ2MZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_voZ9RdYK, 1, m, &cVar_voZ9RdYK_sendMessage);
}

void Heavy_vSwellST::cCast_LQxtcGHL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zCPTTDrw_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_MY96kkHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CH1lcZTe, HV_BINOP_DIVIDE, 0, m, &cBinop_CH1lcZTe_sendMessage);
}

void Heavy_vSwellST::cCast_heU0eX6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UjDJ1fHp_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cCast_Fb7v1Jof_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TzTxvCTS, 0, m, &cVar_TzTxvCTS_sendMessage);
}

void Heavy_vSwellST::cCast_hy1SAzLQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QruafNEq_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cCast_NIXU3Nn7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_t8uZeee0_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cSwitchcase_gMrb7NXy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_8DZiF1Zw_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_8DZiF1Zw_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_V7tYoziN, 1, m, &cDelay_V7tYoziN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NIvUe5BP_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_V7tYoziN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_V7tYoziN, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eCPG84Ls_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jZIojUsY_sendMessage);
  cSwitchcase_aTYlyQeg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_8DZiF1Zw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_V7tYoziN, 0, m, &cDelay_V7tYoziN_sendMessage);
}

void Heavy_vSwellST::cCast_NIvUe5BP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_V7tYoziN, 0, m, &cDelay_V7tYoziN_sendMessage);
}

void Heavy_vSwellST::cVar_IkUoPbGA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OdvKNlxk, HV_BINOP_MULTIPLY, 0, m, &cBinop_OdvKNlxk_sendMessage);
}

void Heavy_vSwellST::cMsg_tNMcBAlP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KzYc7AKu_sendMessage);
}

void Heavy_vSwellST::cSystem_KzYc7AKu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dsQYBWOb_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_OdvKNlxk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_GH26Swof_sendMessage);
}

void Heavy_vSwellST::cBinop_6UjNcrR7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OdvKNlxk, HV_BINOP_MULTIPLY, 1, m, &cBinop_OdvKNlxk_sendMessage);
}

void Heavy_vSwellST::cMsg_dsQYBWOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_6UjNcrR7_sendMessage);
}

void Heavy_vSwellST::cBinop_GH26Swof_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_2EYtQsF0_sendMessage);
}

void Heavy_vSwellST::cBinop_2EYtQsF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_J7sc9j2s_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Oa4sqCzD, m);
}

void Heavy_vSwellST::cBinop_J7sc9j2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_fuWTIfNs, m);
}

void Heavy_vSwellST::cMsg_3ciT6O8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_AdHYysgD_sendMessage);
}

void Heavy_vSwellST::cSystem_AdHYysgD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_R1GGK1A6_sendMessage);
}

void Heavy_vSwellST::cDelay_nlbUy3IG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nlbUy3IG, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9un7sDVD, 0, m, &cDelay_9un7sDVD_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nlbUy3IG, 0, m, &cDelay_nlbUy3IG_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_j1CIUJDo, 1, m, NULL);
}

void Heavy_vSwellST::cDelay_9un7sDVD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9un7sDVD, m);
  cMsg_2SM96m2n_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cSwitchcase_cIaX0l3b_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_7KhGU2qZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cBinop_BQ3Qb3x6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7eSVEeuK_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::hTable_2GB6yxxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4ePgU5Xh_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nlbUy3IG, 2, m, &cDelay_nlbUy3IG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E255CSnW_sendMessage);
}

void Heavy_vSwellST::cMsg_7eSVEeuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_2GB6yxxw, 0, m, &hTable_2GB6yxxw_sendMessage);
}

void Heavy_vSwellST::cBinop_R1GGK1A6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_BQ3Qb3x6_sendMessage);
}

void Heavy_vSwellST::cMsg_2SM96m2n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_2GB6yxxw, 0, m, &hTable_2GB6yxxw_sendMessage);
}

void Heavy_vSwellST::cCast_E255CSnW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nlbUy3IG, 0, m, &cDelay_nlbUy3IG_sendMessage);
}

void Heavy_vSwellST::cMsg_4ePgU5Xh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_9un7sDVD, 2, m, &cDelay_9un7sDVD_sendMessage);
}

void Heavy_vSwellST::cMsg_7KhGU2qZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_j1CIUJDo, 1, m, NULL);
}

void Heavy_vSwellST::cTabhead_PUvqYa8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_69DBDI33, HV_BINOP_SUBTRACT, 0, m, &cBinop_69DBDI33_sendMessage);
}

void Heavy_vSwellST::cMsg_A0WXfCSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9lJLxLPo_sendMessage);
}

void Heavy_vSwellST::cSystem_9lJLxLPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_K6tFWiyc_sendMessage);
}

void Heavy_vSwellST::cVar_HonAkLRB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MM2G6z0l_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cDelay_BtbFu6cI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BtbFu6cI, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_W0mJADVI, 0, m, &cDelay_W0mJADVI_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_I0P2Mz6T, 0, m, &sTabread_I0P2Mz6T_sendMessage);
}

void Heavy_vSwellST::cDelay_W0mJADVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_W0mJADVI, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_I0P2Mz6T, 0, m, &sTabread_I0P2Mz6T_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_W0mJADVI, 0, m, &cDelay_W0mJADVI_sendMessage);
}

void Heavy_vSwellST::sTabread_I0P2Mz6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_N8MUtGKb, HV_BINOP_SUBTRACT, 0, m, &cBinop_N8MUtGKb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_VMGQmFtc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_l0UPWi3w, HV_BINOP_MAX, 0, m, &cBinop_l0UPWi3w_sendMessage);
}

void Heavy_vSwellST::cBinop_K6tFWiyc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VMGQmFtc, HV_BINOP_MULTIPLY, 0, m, &cBinop_VMGQmFtc_sendMessage);
}

void Heavy_vSwellST::cBinop_69DBDI33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j1g4zHmQ_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_I0P2Mz6T, 0, m, &sTabread_I0P2Mz6T_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ue0irnZQ_sendMessage);
}

void Heavy_vSwellST::cSystem_n2xwfQpF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N8MUtGKb, HV_BINOP_SUBTRACT, 1, m, &cBinop_N8MUtGKb_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_W0mJADVI, 2, m, &cDelay_W0mJADVI_sendMessage);
}

void Heavy_vSwellST::cMsg_MM2G6z0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_n2xwfQpF_sendMessage);
}

void Heavy_vSwellST::cMsg_j1g4zHmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BtbFu6cI, 0, m, &cDelay_BtbFu6cI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_W0mJADVI, 0, m, &cDelay_W0mJADVI_sendMessage);
}

void Heavy_vSwellST::cMsg_CMiqw12O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_l0UPWi3w, HV_BINOP_MAX, 1, m, &cBinop_l0UPWi3w_sendMessage);
}

void Heavy_vSwellST::cBinop_l0UPWi3w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_69DBDI33, HV_BINOP_SUBTRACT, 1, m, &cBinop_69DBDI33_sendMessage);
}

void Heavy_vSwellST::cCast_ue0irnZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BtbFu6cI, 0, m, &cDelay_BtbFu6cI_sendMessage);
}

void Heavy_vSwellST::cBinop_pTq67erh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BtbFu6cI, 2, m, &cDelay_BtbFu6cI_sendMessage);
}

void Heavy_vSwellST::cBinop_N8MUtGKb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_pTq67erh_sendMessage);
}

void Heavy_vSwellST::cCast_gbCqjygt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HonAkLRB, 0, m, &cVar_HonAkLRB_sendMessage);
  cMsg_A0WXfCSd_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_PUvqYa8B, 0, m, &cTabhead_PUvqYa8B_sendMessage);
}

void Heavy_vSwellST::cMsg_9mX0KzNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HJRHzIf9_sendMessage);
}

void Heavy_vSwellST::cSystem_HJRHzIf9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ODGrQYvH_sendMessage);
}

void Heavy_vSwellST::cDelay_eOzhrXbw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_eOzhrXbw, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_V2EQm0d9, 0, m, &cDelay_V2EQm0d9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_eOzhrXbw, 0, m, &cDelay_eOzhrXbw_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_N1fYoRVV, 1, m, NULL);
}

void Heavy_vSwellST::cDelay_V2EQm0d9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_V2EQm0d9, m);
  cMsg_pAG4Uit5_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cSwitchcase_Rp5xJ0KU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_3wgTH3IB_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cBinop_UHehgLym_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_U6AQgbQN_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::hTable_sZIntTQa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_As0F8bn8_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_eOzhrXbw, 2, m, &cDelay_eOzhrXbw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8tlqRhzf_sendMessage);
}

void Heavy_vSwellST::cMsg_U6AQgbQN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_sZIntTQa, 0, m, &hTable_sZIntTQa_sendMessage);
}

void Heavy_vSwellST::cBinop_ODGrQYvH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_UHehgLym_sendMessage);
}

void Heavy_vSwellST::cMsg_pAG4Uit5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_sZIntTQa, 0, m, &hTable_sZIntTQa_sendMessage);
}

void Heavy_vSwellST::cCast_8tlqRhzf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_eOzhrXbw, 0, m, &cDelay_eOzhrXbw_sendMessage);
}

void Heavy_vSwellST::cMsg_As0F8bn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_V2EQm0d9, 2, m, &cDelay_V2EQm0d9_sendMessage);
}

void Heavy_vSwellST::cMsg_3wgTH3IB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_N1fYoRVV, 1, m, NULL);
}

void Heavy_vSwellST::cTabhead_4zv4I59K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KVcMBn7F, HV_BINOP_SUBTRACT, 0, m, &cBinop_KVcMBn7F_sendMessage);
}

void Heavy_vSwellST::cMsg_CLi7uevB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Iwg5s3Lo_sendMessage);
}

void Heavy_vSwellST::cSystem_Iwg5s3Lo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_HAjhEkBq_sendMessage);
}

void Heavy_vSwellST::cVar_Z3deqqQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cwflqmc5_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cDelay_E3MVlhOV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_E3MVlhOV, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FOUyjeGS, 0, m, &cDelay_FOUyjeGS_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_3ewLDZRo, 0, m, &sTabread_3ewLDZRo_sendMessage);
}

void Heavy_vSwellST::cDelay_FOUyjeGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FOUyjeGS, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_3ewLDZRo, 0, m, &sTabread_3ewLDZRo_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FOUyjeGS, 0, m, &cDelay_FOUyjeGS_sendMessage);
}

void Heavy_vSwellST::sTabread_3ewLDZRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_r2Tik4xx, HV_BINOP_SUBTRACT, 0, m, &cBinop_r2Tik4xx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_NAqOND6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9A18FjG0, HV_BINOP_MAX, 0, m, &cBinop_9A18FjG0_sendMessage);
}

void Heavy_vSwellST::cBinop_HAjhEkBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NAqOND6g, HV_BINOP_MULTIPLY, 0, m, &cBinop_NAqOND6g_sendMessage);
}

void Heavy_vSwellST::cBinop_KVcMBn7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WgDtBPuo_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_3ewLDZRo, 0, m, &sTabread_3ewLDZRo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BacZSHNi_sendMessage);
}

void Heavy_vSwellST::cSystem_JwseVJid_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r2Tik4xx, HV_BINOP_SUBTRACT, 1, m, &cBinop_r2Tik4xx_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FOUyjeGS, 2, m, &cDelay_FOUyjeGS_sendMessage);
}

void Heavy_vSwellST::cMsg_cwflqmc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JwseVJid_sendMessage);
}

void Heavy_vSwellST::cMsg_WgDtBPuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_E3MVlhOV, 0, m, &cDelay_E3MVlhOV_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FOUyjeGS, 0, m, &cDelay_FOUyjeGS_sendMessage);
}

void Heavy_vSwellST::cMsg_y0Q8zZnj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_9A18FjG0, HV_BINOP_MAX, 1, m, &cBinop_9A18FjG0_sendMessage);
}

void Heavy_vSwellST::cBinop_9A18FjG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KVcMBn7F, HV_BINOP_SUBTRACT, 1, m, &cBinop_KVcMBn7F_sendMessage);
}

void Heavy_vSwellST::cCast_BacZSHNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_E3MVlhOV, 0, m, &cDelay_E3MVlhOV_sendMessage);
}

void Heavy_vSwellST::cBinop_d978rANy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_E3MVlhOV, 2, m, &cDelay_E3MVlhOV_sendMessage);
}

void Heavy_vSwellST::cBinop_r2Tik4xx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_d978rANy_sendMessage);
}

void Heavy_vSwellST::cCast_JbCFTlIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Z3deqqQQ, 0, m, &cVar_Z3deqqQQ_sendMessage);
  cMsg_CLi7uevB_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_4zv4I59K, 0, m, &cTabhead_4zv4I59K_sendMessage);
}

void Heavy_vSwellST::cUnop_wzykGI8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_GxwLKfXu, m);
}

void Heavy_vSwellST::cCast_LiEL1CNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_gMrb7NXy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_npxe7XIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ygZHlHXO_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Yb8FRUaf, 0, m, &cVar_Yb8FRUaf_sendMessage);
}

void Heavy_vSwellST::cCast_Y2xwwoPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZuGnLBEo, HV_BINOP_SUBTRACT, 0, m, &cBinop_ZuGnLBEo_sendMessage);
}

void Heavy_vSwellST::cCast_mHONCX4U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZGcsbFHz, 0, m, &cVar_ZGcsbFHz_sendMessage);
}

void Heavy_vSwellST::cBinop_ZuGnLBEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Z7MFt3HX, 0, m, &cVar_Z7MFt3HX_sendMessage);
}

void Heavy_vSwellST::cSend_ygZHlHXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_idFjLCAi_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_DELjWDJO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_TPflp504_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_KaaF9mUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 25.0f);
  cSwitchcase_5D6OwyNt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_x6ss4zqG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 3.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bwrYCOTk, 0, m, NULL);
}

void Heavy_vSwellST::cSend_ZghCDUeC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_arjXBc33_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_7trazUze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_V7tYoziN, 1, m, &cDelay_V7tYoziN_sendMessage);
}

void Heavy_vSwellST::cBinop_nnpqZKwn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_wzykGI8G_sendMessage);
}

void Heavy_vSwellST::cReceive_uU3P15qo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZuGnLBEo, HV_BINOP_SUBTRACT, 1, m, &cBinop_ZuGnLBEo_sendMessage);
}

void Heavy_vSwellST::cReceive_0QPxbHMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7Pe0Fjx2_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_uCWQdVCF, 0, m, &cVar_uCWQdVCF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kkUcmFIg, 0, m, &cVar_kkUcmFIg_sendMessage);
  cMsg_edjHny9o_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_aqKYmkLt, 0, m, &cVar_aqKYmkLt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Bgp5HMXz, 0, m, &cVar_Bgp5HMXz_sendMessage);
  cMsg_tNMcBAlP_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_IkUoPbGA, 0, m, &cVar_IkUoPbGA_sendMessage);
  cMsg_3ciT6O8j_sendMessage(_c, 0, m);
  cMsg_9mX0KzNG_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_KyJbcFpu, 0, m, &cVar_KyJbcFpu_sendMessage);
  cMsg_CMiqw12O_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_HonAkLRB, 0, m, &cVar_HonAkLRB_sendMessage);
  cMsg_A0WXfCSd_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_PUvqYa8B, 0, m, &cTabhead_PUvqYa8B_sendMessage);
  cMsg_y0Q8zZnj_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Z3deqqQQ, 0, m, &cVar_Z3deqqQQ_sendMessage);
  cMsg_CLi7uevB_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_4zv4I59K, 0, m, &cTabhead_4zv4I59K_sendMessage);
}

void Heavy_vSwellST::cReceive_k2XaLLMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSlice_onMessage(_c, &Context(_c)->cSlice_wlQYKdRs, 0, m, &cSlice_wlQYKdRs_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_Zo2Rhipc, 0, m, &cSlice_Zo2Rhipc_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_P16TrA7Z, 0, m, &cSlice_P16TrA7Z_sendMessage);
}

void Heavy_vSwellST::cReceive_zcsOypYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_VWOZeBDH, m);
}

void Heavy_vSwellST::cReceive_idFjLCAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jOAp28AW_sendMessage(_c, 0, m);
  cMsg_5YYh9Q6l_sendMessage(_c, 0, m);
  cMsg_zPv1oV7r_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cReceive_7vcl7qqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_npxe7XIK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LiEL1CNC_sendMessage);
}

void Heavy_vSwellST::cReceive_OnGDgJ4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ObP4Qio3, 1, m, &cVar_ObP4Qio3_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_Sh5iiyiX, 1, m, &cPack_Sh5iiyiX_sendMessage);
}

void Heavy_vSwellST::cReceive_VCUiqBsQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_Sh5iiyiX, 2, m, &cPack_Sh5iiyiX_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_am5Z1eoa, 1, m, &cDelay_am5Z1eoa_sendMessage);
}

void Heavy_vSwellST::cReceive_s2hhY4Fa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_1I5x3qnT, 1, m, &cPack_1I5x3qnT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gbskxB5t, 1, m, &cVar_gbskxB5t_sendMessage);
}

void Heavy_vSwellST::cReceive_vNa01IX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_1I5x3qnT, 2, m, &cPack_1I5x3qnT_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VMo3SjkN, 1, m, &cDelay_VMo3SjkN_sendMessage);
}

void Heavy_vSwellST::cReceive_J2igMN5p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_nCoaqy6k, 2, m, &cPack_nCoaqy6k_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_p0MVtv2R, 1, m, &cDelay_p0MVtv2R_sendMessage);
}

void Heavy_vSwellST::cReceive_arjXBc33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KyJbcFpu, 1, m, &cVar_KyJbcFpu_sendMessage);
  cMsg_KaaF9mUm_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Yb8FRUaf, 1, m, &cVar_Yb8FRUaf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QEtqqzJj, 1, m, &cVar_QEtqqzJj_sendMessage);
}

void Heavy_vSwellST::cReceive_i8NEW1R3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZghCDUeC_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cReceive_aNRFKlmP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 3.0f, 0, m, &cBinop_7trazUze_sendMessage);
}

void Heavy_vSwellST::cReceive_oi7aVQcc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_CsQvDf7O, m);
}

void Heavy_vSwellST::cReceive_htFf6a5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_fg2c2OPa, m);
}

void Heavy_vSwellST::cReceive_bLgp72MA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Y2xwwoPr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mHONCX4U_sendMessage);
}

void Heavy_vSwellST::cReceive_BcTjIa7S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_nnpqZKwn_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_bTXg0p4V, m);
}




/*
 * Context Process Implementation
 */

int Heavy_vSwellST::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_tabwrite_f(&sTabwrite_j1CIUJDo, VIf(I0));
    __hv_tabwrite_f(&sTabwrite_N1fYoRVV, VIf(I1));
    __hv_varread_f(&sVarf_CsQvDf7O, VOf(Bf0));
    __hv_varread_f(&sVarf_fg2c2OPa, VOf(Bf1));
    __hv_mul_f(VIf(I1), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_Oa4sqCzD, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_fuWTIfNs, VOf(Bf1));
    __hv_rpole_f(&sRPole_IXWYN6yt, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_bTXg0p4V, VOf(Bf0));
    __hv_varread_f(&sVarf_GxwLKfXu, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf3), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_zero_f(VOf(Bf2));
    __hv_gt_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_sqrt_f(VIf(Bf3), VOf(Bf3));
    __hv_and_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf2), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_div_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf1), VIf(Bf0), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_KYqzSBK1, VIf(Bf2), &sEnv_KYqzSBK1_sendMessage);
    __hv_tabread_f(&sTabread_3ewLDZRo, VOf(Bf2));
    __hv_line_f(&sLine_bwrYCOTk, VOf(Bf0));
    __hv_varread_f(&sVarf_VWOZeBDH, VOf(Bf1));
    __hv_pow_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_HoSFLJRe, VOf(Bf0));
    __hv_max_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f);
    __hv_min_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));
    __hv_tabread_f(&sTabread_I0P2Mz6T, VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf1), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_vSwellST::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_vSwellST::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
