/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_VSWELLST_HPP_
#define _HEAVY_CONTEXT_VSWELLST_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalTabread.h"
#include "HvControlBinop.h"
#include "HvControlUnop.h"
#include "HvControlCast.h"
#include "HvSignalLine.h"
#include "HvControlSlice.h"
#include "HvSignalVar.h"
#include "HvControlVar.h"
#include "HvTable.h"
#include "HvSignalTabwrite.h"
#include "HvControlIf.h"
#include "HvSignalRPole.h"
#include "HvSignalEnvelope.h"
#include "HvControlPack.h"
#include "HvControlDelay.h"
#include "HvMath.h"
#include "HvControlSystem.h"
#include "HvSignalDel1.h"
#include "HvControlTabhead.h"

class Heavy_vSwellST : public HeavyContext {

 public:
  Heavy_vSwellST(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_vSwellST();

  const char *getName() override { return "vSwellST"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        ATTACK_LEVEL = 0xCFF35931, // Attack_Level
        ATTACK_MS = 0x4397AE0, // Attack_ms
        MID_LEVEL = 0x73ACB90E, // Mid_Level
        MID_MS = 0x4675584E, // Mid_ms
        RELEASE_MS = 0x558F437A, // Release_ms
        SHAPE = 0x8D204657, // Shape
        SUBENV_LEVEL = 0x2D669F6F, // SubEnv_Level
        THRESHOLD_HIGH = 0x7BABB594, // Threshold_High
        THRESHOLD_LOW = 0xA0E82E9F, // Threshold_Low
        THRESHOLD_STRICT = 0x145892E8, // Threshold_Strict
        TRIGGER_DELAY = 0xCB36B160, // Trigger_Delay
        TRIGGER_EXT = 0x5DF5B524, // Trigger_EXT
        TRIGGER_LEFT = 0x4E6E7C40, // Trigger_Left
        TRIGGER_RIGHT = 0xB181ABB6, // Trigger_Right
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void sEnv_KYqzSBK1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_4dIJTwo2_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_kUsIvDYb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_Ymt457hZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZmkMeviw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_6IGIQnSW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6tpvPVNA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7WS47zez_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5nKaYhnl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_D5i7VEJr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mIQ4Qsds_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3HzM9i9Q_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_zQMP3oZY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_xkVE3V0n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_UK3NEzr3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_GT4G7csp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Tbb3lmpv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EKaVJZ1j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IO3qDjUu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BpAjvMfZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gdoA3WuY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_LIxG5f6G_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_YsdepIbw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jckertfo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_P1ao0gKl_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_FoExB7X5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BkUQpZnt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZGcsbFHz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Z7MFt3HX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HwrEeF2d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mRa69i1T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_a1BcItA9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rAkVL9El_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_wlQYKdRs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_Zo2Rhipc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_P16TrA7Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kkUcmFIg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_EIpUqWTD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_YDljjyra_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_RfA4GWQj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cQYm8zan_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_BfvfQnyV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WoMY3zTr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3H8MbAcW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Pqcbd7Is_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PkR58g3y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9rhfxANs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P6KZwdpr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XeRijmgP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AKCN3yk0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IPbtG8h7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2FU5w0tr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4eKeAMaO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_aTYlyQeg_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_am5Z1eoa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_109l0JOm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DlkEVMkG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_Sh5iiyiX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QEtqqzJj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jOAp28AW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jZIojUsY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eCPG84Ls_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Db3pssJs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O5POlD0O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_PJNHKYSp_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_VMo3SjkN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F9uD42R5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KInwcSJk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_1I5x3qnT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ObP4Qio3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5YYh9Q6l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fsYW8ok1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1ZTPLdfn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Omb0Mf8B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JkmV22eJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_fTIcYPXn_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_p0MVtv2R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PYRpD43v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rRaVS59Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_nCoaqy6k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gbskxB5t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zPv1oV7r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_M0q3z2iJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1i1lUS7C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Wr9ATiPN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XQVJYPTM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_TPflp504_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_9UWOtESQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Yb8FRUaf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KyJbcFpu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_edjHny9o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_f8KL77AI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_HEMITfPT_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_tpmZPgsD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RaB2hj32_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7Pe0Fjx2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_sbX5AdrU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uCWQdVCF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hlBMrxzt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vmgAQlWi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IcXHbkvV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ywQh6Pvk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_eiZzYgbq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_odXb0g8N_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_OqDWVPQz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XCYas3Ub_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5D6OwyNt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_bqRkZPHa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_phYRUGJM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TzTxvCTS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Bgp5HMXz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_sV0U7uvu_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_tZXAdLXS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aqKYmkLt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_T4b66XsC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_voZ9RdYK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_GwtEzfP9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_W6Dp6ub4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FipTWYTb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J5WOijBI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AuFgRGl7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qzLzcXzt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_izqO1xZu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_t8uZeee0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UjDJ1fHp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nWyPTtFH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xFR5iLZR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EXHg3tMu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CH1lcZTe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bi8b92lz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gnpXa34O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0qDTa5wx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mbRQkDJB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iCPfI3Ho_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RlsL4rsg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8jHfQ2MZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zCPTTDrw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QruafNEq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xcHFjkjw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LhF5Firr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LQxtcGHL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MY96kkHS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_heU0eX6W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Fb7v1Jof_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hy1SAzLQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NIXU3Nn7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_gMrb7NXy_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_V7tYoziN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8DZiF1Zw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NIvUe5BP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IkUoPbGA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tNMcBAlP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_KzYc7AKu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OdvKNlxk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6UjNcrR7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dsQYBWOb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GH26Swof_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2EYtQsF0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J7sc9j2s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3ciT6O8j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_AdHYysgD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_nlbUy3IG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_9un7sDVD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_cIaX0l3b_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_BQ3Qb3x6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_2GB6yxxw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7eSVEeuK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R1GGK1A6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2SM96m2n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_E255CSnW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4ePgU5Xh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7KhGU2qZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_PUvqYa8B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A0WXfCSd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_9lJLxLPo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HonAkLRB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_BtbFu6cI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_W0mJADVI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_I0P2Mz6T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VMGQmFtc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K6tFWiyc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_69DBDI33_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_n2xwfQpF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MM2G6z0l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_j1g4zHmQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CMiqw12O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_l0UPWi3w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ue0irnZQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pTq67erh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N8MUtGKb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gbCqjygt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9mX0KzNG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_HJRHzIf9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_eOzhrXbw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_V2EQm0d9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Rp5xJ0KU_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_UHehgLym_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_sZIntTQa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U6AQgbQN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ODGrQYvH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pAG4Uit5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8tlqRhzf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_As0F8bn8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3wgTH3IB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_4zv4I59K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CLi7uevB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Iwg5s3Lo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Z3deqqQQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_E3MVlhOV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_FOUyjeGS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_3ewLDZRo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NAqOND6g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HAjhEkBq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KVcMBn7F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JwseVJid_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cwflqmc5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WgDtBPuo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y0Q8zZnj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9A18FjG0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BacZSHNi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d978rANy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r2Tik4xx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JbCFTlIF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_wzykGI8G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LiEL1CNC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_npxe7XIK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Y2xwwoPr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mHONCX4U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZuGnLBEo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ygZHlHXO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DELjWDJO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KaaF9mUm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x6ss4zqG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ZghCDUeC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7trazUze_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nnpqZKwn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_uU3P15qo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0QPxbHMo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_k2XaLLMa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_zcsOypYA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_idFjLCAi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7vcl7qqh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_OnGDgJ4Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_VCUiqBsQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_s2hhY4Fa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vNa01IX8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_J2igMN5p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_arjXBc33_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_i8NEW1R3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_aNRFKlmP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_oi7aVQcc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_htFf6a5M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bLgp72MA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_BcTjIa7S_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalTabwrite sTabwrite_j1CIUJDo;
  SignalTabwrite sTabwrite_N1fYoRVV;
  SignalRPole sRPole_IXWYN6yt;
  SignalEnvelope sEnv_KYqzSBK1;
  SignalTabread sTabread_3ewLDZRo;
  SignalLine sLine_bwrYCOTk;
  SignalTabread sTabread_I0P2Mz6T;
  ControlSlice cSlice_kUsIvDYb;
  ControlSlice cSlice_Ymt457hZ;
  ControlVar cVar_ZmkMeviw;
  ControlIf cIf_6IGIQnSW;
  ControlBinop cBinop_5nKaYhnl;
  ControlSlice cSlice_zQMP3oZY;
  ControlSlice cSlice_xkVE3V0n;
  ControlVar cVar_UK3NEzr3;
  ControlIf cIf_GT4G7csp;
  ControlBinop cBinop_IO3qDjUu;
  ControlVar cVar_ZGcsbFHz;
  ControlVar cVar_Z7MFt3HX;
  ControlBinop cBinop_HwrEeF2d;
  ControlBinop cBinop_mRa69i1T;
  ControlSlice cSlice_wlQYKdRs;
  ControlSlice cSlice_Zo2Rhipc;
  ControlSlice cSlice_P16TrA7Z;
  ControlVar cVar_kkUcmFIg;
  ControlIf cIf_RfA4GWQj;
  ControlBinop cBinop_cQYm8zan;
  ControlIf cIf_BfvfQnyV;
  ControlIf cIf_WoMY3zTr;
  ControlIf cIf_3H8MbAcW;
  ControlIf cIf_Pqcbd7Is;
  ControlBinop cBinop_PkR58g3y;
  ControlBinop cBinop_9rhfxANs;
  ControlBinop cBinop_P6KZwdpr;
  ControlBinop cBinop_4eKeAMaO;
  ControlDelay cDelay_am5Z1eoa;
  ControlPack cPack_Sh5iiyiX;
  ControlVar cVar_QEtqqzJj;
  ControlDelay cDelay_VMo3SjkN;
  ControlPack cPack_1I5x3qnT;
  ControlVar cVar_ObP4Qio3;
  ControlDelay cDelay_p0MVtv2R;
  ControlPack cPack_nCoaqy6k;
  ControlVar cVar_gbskxB5t;
  ControlVar cVar_Yb8FRUaf;
  ControlVar cVar_KyJbcFpu;
  SignalVarf sVarf_HoSFLJRe;
  ControlDelay cDelay_tpmZPgsD;
  ControlVar cVar_uCWQdVCF;
  ControlBinop cBinop_vmgAQlWi;
  ControlBinop cBinop_IcXHbkvV;
  ControlBinop cBinop_ywQh6Pvk;
  ControlVar cVar_eiZzYgbq;
  ControlSlice cSlice_bqRkZPHa;
  ControlSlice cSlice_phYRUGJM;
  ControlVar cVar_TzTxvCTS;
  ControlVar cVar_Bgp5HMXz;
  ControlVar cVar_aqKYmkLt;
  ControlVar cVar_T4b66XsC;
  ControlVar cVar_voZ9RdYK;
  ControlSlice cSlice_GwtEzfP9;
  ControlSlice cSlice_W6Dp6ub4;
  ControlBinop cBinop_FipTWYTb;
  ControlBinop cBinop_J5WOijBI;
  ControlBinop cBinop_AuFgRGl7;
  ControlBinop cBinop_qzLzcXzt;
  ControlBinop cBinop_izqO1xZu;
  ControlBinop cBinop_nWyPTtFH;
  ControlBinop cBinop_xFR5iLZR;
  ControlBinop cBinop_EXHg3tMu;
  ControlBinop cBinop_CH1lcZTe;
  ControlBinop cBinop_8jHfQ2MZ;
  ControlBinop cBinop_MY96kkHS;
  ControlDelay cDelay_V7tYoziN;
  ControlVar cVar_IkUoPbGA;
  ControlBinop cBinop_OdvKNlxk;
  ControlBinop cBinop_6UjNcrR7;
  SignalVarf sVarf_fuWTIfNs;
  ControlBinop cBinop_GH26Swof;
  ControlBinop cBinop_2EYtQsF0;
  ControlBinop cBinop_J7sc9j2s;
  SignalVarf sVarf_Oa4sqCzD;
  ControlDelay cDelay_nlbUy3IG;
  ControlDelay cDelay_9un7sDVD;
  ControlBinop cBinop_BQ3Qb3x6;
  HvTable hTable_2GB6yxxw;
  ControlBinop cBinop_R1GGK1A6;
  ControlTabhead cTabhead_PUvqYa8B;
  ControlVar cVar_HonAkLRB;
  ControlDelay cDelay_BtbFu6cI;
  ControlDelay cDelay_W0mJADVI;
  ControlBinop cBinop_VMGQmFtc;
  ControlBinop cBinop_K6tFWiyc;
  ControlBinop cBinop_69DBDI33;
  ControlBinop cBinop_l0UPWi3w;
  ControlBinop cBinop_pTq67erh;
  ControlBinop cBinop_N8MUtGKb;
  ControlDelay cDelay_eOzhrXbw;
  ControlDelay cDelay_V2EQm0d9;
  ControlBinop cBinop_UHehgLym;
  HvTable hTable_sZIntTQa;
  ControlBinop cBinop_ODGrQYvH;
  ControlTabhead cTabhead_4zv4I59K;
  ControlVar cVar_Z3deqqQQ;
  ControlDelay cDelay_E3MVlhOV;
  ControlDelay cDelay_FOUyjeGS;
  ControlBinop cBinop_NAqOND6g;
  ControlBinop cBinop_HAjhEkBq;
  ControlBinop cBinop_KVcMBn7F;
  ControlBinop cBinop_9A18FjG0;
  ControlBinop cBinop_d978rANy;
  ControlBinop cBinop_r2Tik4xx;
  ControlBinop cBinop_ZuGnLBEo;
  ControlBinop cBinop_DELjWDJO;
  ControlBinop cBinop_7trazUze;
  ControlBinop cBinop_nnpqZKwn;
  SignalVarf sVarf_VWOZeBDH;
  SignalVarf sVarf_CsQvDf7O;
  SignalVarf sVarf_fg2c2OPa;
  SignalVarf sVarf_GxwLKfXu;
  SignalVarf sVarf_bTXg0p4V;
};

#endif // _HEAVY_CONTEXT_VSWELLST_HPP_
